// Optimized
/*
   ┏━━━┓╱╱╱╱╱┏┓╱╱┏┓╱╱╱╱╱┏┓╱╱
   ┃┏━┓┃╱╱╱╱╱┃┃╱╱┃┃╱╱╱╱╱┃┃╱╱╱
   ┃┗━┛┣┓┏┳━━┫┃┏┓┃┃╱╱┏━━┫┗━┳━━┓
   ┃┏━━┫┃┃┃┏┓┃┗┛┃┃┃╱┏┫┏┓┃┏┓┃━━┫
   ┃┃╱╱┃┗┛┃┃┃┃┏┓┃┃┗━┛┃┏┓┃┗┛┣━━┃
   ┗┛╱╱┗━━┻┛┗┻┛┗┛┗━━━┻┛┗┻━━┻━━┛
    ━━━━━━━━━━━━━━━━━━━━━━━━━━

    Copyright (c) 2022 Punk Labs LLC

    This section is part of OneTrick

    OneTrick is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    OneTrick is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    OneTrick.  If not, see <http://www.gnu.org/licenses/>.
*/

use faust_types::*;




pub struct DSP_Cowbell3SIG0 {
	iRec1: [i32;2],
}

impl DSP_Cowbell3SIG0 {
	
	fn get_num_inputsDSP_Cowbell3SIG0(&self) -> i32 {
		return 0;
	}
	fn get_num_outputsDSP_Cowbell3SIG0(&self) -> i32 {
		return 1;
	}
	
	fn instance_initDSP_Cowbell3SIG0(&mut self, sample_rate: i32) {
		for l0 in 0..2 {
			self.iRec1[(l0) as usize] = 0;
		}
	}
	
	fn fillDSP_Cowbell3SIG0(&mut self, count: i32, table: &mut[F32]) {
		for i1 in 0..count {
			self.iRec1[0] = i32::wrapping_add(self.iRec1[1], 1);
			let mut fTemp0: F32 = ((i32::wrapping_add(self.iRec1[0], -1)) as F32);
			table[(i1) as usize] = F32::max(0.0, F32::min(2.0, F32::powf(1e+01, 0.05 * (0.0 - 0.0235 * (8096.0 - fTemp0))))) * (((((7.2e+03 - fTemp0) < 3824.0) as i32)) as F32);
			self.iRec1[1] = self.iRec1[0];
		}
	}

}


pub fn newDSP_Cowbell3SIG0() -> DSP_Cowbell3SIG0 { 
	DSP_Cowbell3SIG0 {
		iRec1: [0;2],
	}
}

pub struct DSP_Cowbell3SIG1 {
	iRec7: [i32;2],
}

impl DSP_Cowbell3SIG1 {
	
	fn get_num_inputsDSP_Cowbell3SIG1(&self) -> i32 {
		return 0;
	}
	fn get_num_outputsDSP_Cowbell3SIG1(&self) -> i32 {
		return 1;
	}
	
	fn instance_initDSP_Cowbell3SIG1(&mut self, sample_rate: i32) {
		for l5 in 0..2 {
			self.iRec7[(l5) as usize] = 0;
		}
	}
	
	fn fillDSP_Cowbell3SIG1(&mut self, count: i32, table: &mut[F32]) {
		for i2 in 0..count {
			self.iRec7[0] = i32::wrapping_add(self.iRec7[1], 1);
			table[(i2) as usize] = 0.2819 * F32::powf(2.0, 0.16 * ((i32::wrapping_add(self.iRec7[0], -1)) as F32));
			self.iRec7[1] = self.iRec7[0];
		}
	}

}


pub fn newDSP_Cowbell3SIG1() -> DSP_Cowbell3SIG1 { 
	DSP_Cowbell3SIG1 {
		iRec7: [0;2],
	}
}

pub struct DSP_Cowbell3SIG2 {
	iVec1: [i32;2],
	iRec10: [i32;2],
}

impl DSP_Cowbell3SIG2 {
	
	fn get_num_inputsDSP_Cowbell3SIG2(&self) -> i32 {
		return 0;
	}
	fn get_num_outputsDSP_Cowbell3SIG2(&self) -> i32 {
		return 1;
	}
	
	fn instance_initDSP_Cowbell3SIG2(&mut self, sample_rate: i32) {
		for l10 in 0..2 {
			self.iVec1[(l10) as usize] = 0;
		}
		for l11 in 0..2 {
			self.iRec10[(l11) as usize] = 0;
		}
	}
	
	fn fillDSP_Cowbell3SIG2(&mut self, count: i32, table: &mut[F32]) {
		for i3 in 0..count {
			self.iVec1[0] = 1;
			self.iRec10[0] = (i32::wrapping_add(self.iVec1[1], self.iRec10[1])) % 1024;
			table[(i3) as usize] = F32::sin(0.0061359233 * ((self.iRec10[0]) as F32));
			self.iVec1[1] = self.iVec1[0];
			self.iRec10[1] = self.iRec10[0];
		}
	}

}


pub fn newDSP_Cowbell3SIG2() -> DSP_Cowbell3SIG2 { 
	DSP_Cowbell3SIG2 {
		iVec1: [0;2],
		iRec10: [0;2],
	}
}

pub struct DSP_Cowbell3SIG3 {
	iRec18: [i32;2],
}

impl DSP_Cowbell3SIG3 {
	
	fn get_num_inputsDSP_Cowbell3SIG3(&self) -> i32 {
		return 0;
	}
	fn get_num_outputsDSP_Cowbell3SIG3(&self) -> i32 {
		return 1;
	}
	
	fn instance_initDSP_Cowbell3SIG3(&mut self, sample_rate: i32) {
		for l18 in 0..2 {
			self.iRec18[(l18) as usize] = 0;
		}
	}
	
	fn fillDSP_Cowbell3SIG3(&mut self, count: i32, table: &mut[F32]) {
		for i4 in 0..count {
			self.iRec18[0] = i32::wrapping_add(self.iRec18[1], 1);
			table[(i4) as usize] = F32::powf(2.0, 0.083333336 * (0.062515266 * ((i32::wrapping_add(self.iRec18[0], -1)) as F32) + -128.0));
			self.iRec18[1] = self.iRec18[0];
		}
	}

}


pub fn newDSP_Cowbell3SIG3() -> DSP_Cowbell3SIG3 { 
	DSP_Cowbell3SIG3 {
		iRec18: [0;2],
	}
}
static mut iDSP_Cowbell3SIG4Wave0: [i32;100] = [1,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,16,16,17,18,18,19,20,21,22,23,24,25,26,27,28,30,31,33,34,36,37,38,39,41,42,44,46,47,49,51,53,54,56,58,60,62,64,66,68,70,72,74,76,79,82,85,88,91,94,98,102,106,110,115,120,125,130,135,141,147,153,159,165,171,178,185,193,202,211,232,243,254,255];

pub struct DSP_Cowbell3SIG4 {
	iDSP_Cowbell3SIG4Wave0_idx: i32,
}

impl DSP_Cowbell3SIG4 {
	
	fn get_num_inputsDSP_Cowbell3SIG4(&self) -> i32 {
		return 0;
	}
	fn get_num_outputsDSP_Cowbell3SIG4(&self) -> i32 {
		return 1;
	}
	
	fn instance_initDSP_Cowbell3SIG4(&mut self, sample_rate: i32) {
		self.iDSP_Cowbell3SIG4Wave0_idx = 0;
	}
	
	fn fillDSP_Cowbell3SIG4(&mut self, count: i32, table: &mut[i32]) {
		for i5 in 0..count {
			table[(i5) as usize] = unsafe { iDSP_Cowbell3SIG4Wave0[(self.iDSP_Cowbell3SIG4Wave0_idx) as usize] };
			self.iDSP_Cowbell3SIG4Wave0_idx = (i32::wrapping_add(1, self.iDSP_Cowbell3SIG4Wave0_idx)) % 100;
		}
	}

}


pub fn newDSP_Cowbell3SIG4() -> DSP_Cowbell3SIG4 { 
	DSP_Cowbell3SIG4 {
		iDSP_Cowbell3SIG4Wave0_idx: 0,
	}
}
static mut iDSP_Cowbell3SIG5Wave0: [i32;100] = [-128,-116,-104,-95,-85,-76,-68,-61,-56,-52,-49,-46,-43,-41,-39,-37,-35,-33,-32,-31,-30,-29,-28,-27,-26,-25,-24,-23,-22,-21,-20,-19,-18,-17,-16,-15,-14,-13,-12,-11,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,38,40,43,46,49,53,58,65,73,82,92,103,115,127];

pub struct DSP_Cowbell3SIG5 {
	iDSP_Cowbell3SIG5Wave0_idx: i32,
}

impl DSP_Cowbell3SIG5 {
	
	fn get_num_inputsDSP_Cowbell3SIG5(&self) -> i32 {
		return 0;
	}
	fn get_num_outputsDSP_Cowbell3SIG5(&self) -> i32 {
		return 1;
	}
	
	fn instance_initDSP_Cowbell3SIG5(&mut self, sample_rate: i32) {
		self.iDSP_Cowbell3SIG5Wave0_idx = 0;
	}
	
	fn fillDSP_Cowbell3SIG5(&mut self, count: i32, table: &mut[i32]) {
		for i6 in 0..count {
			table[(i6) as usize] = unsafe { iDSP_Cowbell3SIG5Wave0[(self.iDSP_Cowbell3SIG5Wave0_idx) as usize] };
			self.iDSP_Cowbell3SIG5Wave0_idx = (i32::wrapping_add(1, self.iDSP_Cowbell3SIG5Wave0_idx)) % 100;
		}
	}

}


pub fn newDSP_Cowbell3SIG5() -> DSP_Cowbell3SIG5 { 
	DSP_Cowbell3SIG5 {
		iDSP_Cowbell3SIG5Wave0_idx: 0,
	}
}
static mut ftbl0DSP_Cowbell3SIG0: [F32;16384] = [0.0;16384];
fn DSP_Cowbell3_faustpower2_f(value: F32) -> F32 {
	return value * value;
}
static mut ftbl1DSP_Cowbell3SIG1: [F32;144] = [0.0;144];
static mut ftbl2DSP_Cowbell3SIG2: [F32;1024] = [0.0;1024];
static mut ftbl3DSP_Cowbell3SIG3: [F32;4096] = [0.0;4096];
static mut itbl4DSP_Cowbell3SIG4: [i32;100] = [0;100];
static mut itbl5DSP_Cowbell3SIG5: [i32;100] = [0;100];

#[cfg_attr(feature = "default-boxed", derive(default_boxed::DefaultBoxed))]
pub struct DSP_Cowbell3 {
	fSampleRate: i32,
	fConst0: F32,
	fConst4: F32,
	fButton0: F32,
	fVec0: [F32;2],
	fHslider0: F32,
	fEntry0: F32,
	fRec5: [F32;2],
	fRec4: [F32;2],
	fRec6: [F32;2],
	fRec8: [F32;2],
	fConst5: F32,
	fConst6: F32,
	fRec9: [F32;2],
	fRec3: [F32;2],
	fRec2: [F32;2],
	fRec13: [F32;2],
	fRec14: [F32;2],
	fRec15: [F32;2],
	fRec16: [F32;2],
	fRec12: [F32;2],
	fRec11: [F32;2],
	fConst7: F32,
	fConst8: F32,
	iConst9: i32,
	iRec21: [i32;2],
	iConst10: i32,
	iRec22: [i32;2],
	fConst11: F32,
	fConst12: F32,
	fRec23: [F32;2],
	fRec20: [F32;2],
	fRec19: [F32;2],
	fHslider1: F32,
	fHslider2: F32,
	fConst13: F32,
	fRec17: [F32;2],
	fRec26: [F32;2],
	fRec27: [F32;2],
	fRec28: [F32;2],
	fRec25: [F32;2],
	fRec24: [F32;2],
	fConst14: F32,
	fRec29: [F32;2],
	fRec33: [F32;2],
	fRec34: [F32;2],
	fRec35: [F32;2],
	fRec32: [F32;2],
	fRec31: [F32;2],
	fConst15: F32,
	fRec36: [F32;2],
	fVec2: [F32;2],
	fConst16: F32,
	fConst17: F32,
	fRec0: [F32;2],
	fHslider3: F32,
	fHslider4: F32,
	fHslider5: F32,
}

impl FaustDsp for DSP_Cowbell3 {
	type T = F32;
		
	fn new() -> DSP_Cowbell3 { 
		DSP_Cowbell3 {
			fSampleRate: 0,
			fConst0: 0.0,
			fConst4: 0.0,
			fButton0: 0.0,
			fVec0: [0.0;2],
			fHslider0: 0.0,
			fEntry0: 0.0,
			fRec5: [0.0;2],
			fRec4: [0.0;2],
			fRec6: [0.0;2],
			fRec8: [0.0;2],
			fConst5: 0.0,
			fConst6: 0.0,
			fRec9: [0.0;2],
			fRec3: [0.0;2],
			fRec2: [0.0;2],
			fRec13: [0.0;2],
			fRec14: [0.0;2],
			fRec15: [0.0;2],
			fRec16: [0.0;2],
			fRec12: [0.0;2],
			fRec11: [0.0;2],
			fConst7: 0.0,
			fConst8: 0.0,
			iConst9: 0,
			iRec21: [0;2],
			iConst10: 0,
			iRec22: [0;2],
			fConst11: 0.0,
			fConst12: 0.0,
			fRec23: [0.0;2],
			fRec20: [0.0;2],
			fRec19: [0.0;2],
			fHslider1: 0.0,
			fHslider2: 0.0,
			fConst13: 0.0,
			fRec17: [0.0;2],
			fRec26: [0.0;2],
			fRec27: [0.0;2],
			fRec28: [0.0;2],
			fRec25: [0.0;2],
			fRec24: [0.0;2],
			fConst14: 0.0,
			fRec29: [0.0;2],
			fRec33: [0.0;2],
			fRec34: [0.0;2],
			fRec35: [0.0;2],
			fRec32: [0.0;2],
			fRec31: [0.0;2],
			fConst15: 0.0,
			fRec36: [0.0;2],
			fVec2: [0.0;2],
			fConst16: 0.0,
			fConst17: 0.0,
			fRec0: [0.0;2],
			fHslider3: 0.0,
			fHslider4: 0.0,
			fHslider5: 0.0,
		}
	}
	fn metadata(&self, m: &mut dyn Meta) { 
		m.declare("basics.lib/name", "Faust Basic Element Library");
		m.declare("basics.lib/sAndH:author", "Romain Michon");
		m.declare("basics.lib/tabulate:author", "Stephane Letz");
		m.declare("basics.lib/version", "0.9");
		m.declare("filename", "main.dsp");
		m.declare("filters.lib/highpass:author", "Julius O. Smith III");
		m.declare("filters.lib/highpass:copyright", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m.declare("filters.lib/lowpass0_highpass1", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m.declare("filters.lib/lowpass0_highpass1:author", "Julius O. Smith III");
		m.declare("filters.lib/name", "Faust Filters Library");
		m.declare("filters.lib/tf1:author", "Julius O. Smith III");
		m.declare("filters.lib/tf1:copyright", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m.declare("filters.lib/tf1:license", "MIT-style STK-4.3 license");
		m.declare("filters.lib/tf1s:author", "Julius O. Smith III");
		m.declare("filters.lib/tf1s:copyright", "Copyright (C) 2003-2019 by Julius O. Smith III <jos@ccrma.stanford.edu>");
		m.declare("filters.lib/tf1s:license", "MIT-style STK-4.3 license");
		m.declare("filters.lib/version", "0.3");
		m.declare("interpolators.lib/interpolate_linear:author", "Stéphane Letz");
		m.declare("interpolators.lib/interpolate_linear:licence", "MIT");
		m.declare("interpolators.lib/name", "Faust Interpolator Library");
		m.declare("interpolators.lib/version", "0.3");
		m.declare("maths.lib/author", "GRAME");
		m.declare("maths.lib/copyright", "GRAME");
		m.declare("maths.lib/license", "LGPL with exception");
		m.declare("maths.lib/name", "Faust Math Library");
		m.declare("maths.lib/version", "2.5");
		m.declare("name", "main");
		m.declare("oscillators.lib/name", "Faust Oscillator Library");
		m.declare("oscillators.lib/version", "0.3");
		m.declare("platform.lib/name", "Generic Platform Library");
		m.declare("platform.lib/version", "0.3");
		m.declare("signals.lib/name", "Faust Signal Routing Library");
		m.declare("signals.lib/version", "0.3");
	}

	fn get_sample_rate(&self) -> i32 {
		return self.fSampleRate;
	}
	fn get_num_inputs(&self) -> i32 {
		return 0;
	}
	fn get_num_outputs(&self) -> i32 {
		return 3;
	}
	
	fn class_init(sample_rate: i32) {
		let mut sig0: DSP_Cowbell3SIG0 = newDSP_Cowbell3SIG0();
		sig0.instance_initDSP_Cowbell3SIG0(sample_rate);
		sig0.fillDSP_Cowbell3SIG0(16384, unsafe { &mut ftbl0DSP_Cowbell3SIG0 });
		let mut sig1: DSP_Cowbell3SIG1 = newDSP_Cowbell3SIG1();
		sig1.instance_initDSP_Cowbell3SIG1(sample_rate);
		sig1.fillDSP_Cowbell3SIG1(144, unsafe { &mut ftbl1DSP_Cowbell3SIG1 });
		let mut sig2: DSP_Cowbell3SIG2 = newDSP_Cowbell3SIG2();
		sig2.instance_initDSP_Cowbell3SIG2(sample_rate);
		sig2.fillDSP_Cowbell3SIG2(1024, unsafe { &mut ftbl2DSP_Cowbell3SIG2 });
		let mut sig3: DSP_Cowbell3SIG3 = newDSP_Cowbell3SIG3();
		sig3.instance_initDSP_Cowbell3SIG3(sample_rate);
		sig3.fillDSP_Cowbell3SIG3(4096, unsafe { &mut ftbl3DSP_Cowbell3SIG3 });
		let mut sig4: DSP_Cowbell3SIG4 = newDSP_Cowbell3SIG4();
		sig4.instance_initDSP_Cowbell3SIG4(sample_rate);
		sig4.fillDSP_Cowbell3SIG4(100, unsafe { &mut itbl4DSP_Cowbell3SIG4 });
		let mut sig5: DSP_Cowbell3SIG5 = newDSP_Cowbell3SIG5();
		sig5.instance_initDSP_Cowbell3SIG5(sample_rate);
		sig5.fillDSP_Cowbell3SIG5(100, unsafe { &mut itbl5DSP_Cowbell3SIG5 });
	}
	fn instance_reset_params(&mut self) {
		self.fButton0 = 0.0;
		self.fHslider0 = 0.0;
		self.fEntry0 = 0.0;
		self.fHslider1 = 36.0;
		self.fHslider2 = 0.0;
		self.fHslider3 = 0.0;
		self.fHslider4 = 0.0;
		self.fHslider5 = 2e+01;
	}
	fn instance_clear(&mut self) {
		for l1 in 0..2 {
			self.fVec0[(l1) as usize] = 0.0;
		}
		for l2 in 0..2 {
			self.fRec5[(l2) as usize] = 0.0;
		}
		for l3 in 0..2 {
			self.fRec4[(l3) as usize] = 0.0;
		}
		for l4 in 0..2 {
			self.fRec6[(l4) as usize] = 0.0;
		}
		for l6 in 0..2 {
			self.fRec8[(l6) as usize] = 0.0;
		}
		for l7 in 0..2 {
			self.fRec9[(l7) as usize] = 0.0;
		}
		for l8 in 0..2 {
			self.fRec3[(l8) as usize] = 0.0;
		}
		for l9 in 0..2 {
			self.fRec2[(l9) as usize] = 0.0;
		}
		for l12 in 0..2 {
			self.fRec13[(l12) as usize] = 0.0;
		}
		for l13 in 0..2 {
			self.fRec14[(l13) as usize] = 0.0;
		}
		for l14 in 0..2 {
			self.fRec15[(l14) as usize] = 0.0;
		}
		for l15 in 0..2 {
			self.fRec16[(l15) as usize] = 0.0;
		}
		for l16 in 0..2 {
			self.fRec12[(l16) as usize] = 0.0;
		}
		for l17 in 0..2 {
			self.fRec11[(l17) as usize] = 0.0;
		}
		for l19 in 0..2 {
			self.iRec21[(l19) as usize] = 0;
		}
		for l20 in 0..2 {
			self.iRec22[(l20) as usize] = 0;
		}
		for l21 in 0..2 {
			self.fRec23[(l21) as usize] = 0.0;
		}
		for l22 in 0..2 {
			self.fRec20[(l22) as usize] = 0.0;
		}
		for l23 in 0..2 {
			self.fRec19[(l23) as usize] = 0.0;
		}
		for l24 in 0..2 {
			self.fRec17[(l24) as usize] = 0.0;
		}
		for l25 in 0..2 {
			self.fRec26[(l25) as usize] = 0.0;
		}
		for l26 in 0..2 {
			self.fRec27[(l26) as usize] = 0.0;
		}
		for l27 in 0..2 {
			self.fRec28[(l27) as usize] = 0.0;
		}
		for l28 in 0..2 {
			self.fRec25[(l28) as usize] = 0.0;
		}
		for l29 in 0..2 {
			self.fRec24[(l29) as usize] = 0.0;
		}
		for l30 in 0..2 {
			self.fRec29[(l30) as usize] = 0.0;
		}
		for l31 in 0..2 {
			self.fRec33[(l31) as usize] = 0.0;
		}
		for l32 in 0..2 {
			self.fRec34[(l32) as usize] = 0.0;
		}
		for l33 in 0..2 {
			self.fRec35[(l33) as usize] = 0.0;
		}
		for l34 in 0..2 {
			self.fRec32[(l34) as usize] = 0.0;
		}
		for l35 in 0..2 {
			self.fRec31[(l35) as usize] = 0.0;
		}
		for l36 in 0..2 {
			self.fRec36[(l36) as usize] = 0.0;
		}
		for l37 in 0..2 {
			self.fVec2[(l37) as usize] = 0.0;
		}
		for l38 in 0..2 {
			self.fRec0[(l38) as usize] = 0.0;
		}
	}
	fn instance_constants(&mut self, sample_rate: i32) {
		self.fSampleRate = sample_rate;
		self.fConst0 = F32::min(1.92e+05, F32::max(1.0, ((self.fSampleRate) as F32)));
		let mut fConst1: F32 = F32::tan(62.831852 / self.fConst0);
		let mut fConst2: F32 = 1.0 / fConst1;
		let mut fConst3: F32 = fConst2 + 1.0;
		self.fConst4 = (1.0 - fConst2) / fConst3;
		self.fConst5 = F32::max(1.0, 0.001 * self.fConst0);
		self.fConst6 = 2.0 * self.fConst5;
		self.fConst7 = ((unsafe { itbl4DSP_Cowbell3SIG4[60] }) as F32);
		self.fConst8 = ((unsafe { itbl4DSP_Cowbell3SIG4[91] }) as F32);
		self.iConst9 = unsafe { itbl5DSP_Cowbell3SIG5[54] };
		self.iConst10 = unsafe { itbl5DSP_Cowbell3SIG5[50] };
		self.fConst11 = 0.64285713 * self.fConst0;
		self.fConst12 = ((unsafe { itbl4DSP_Cowbell3SIG4[98] }) as F32);
		self.fConst13 = 27143.6 / self.fConst0;
		self.fConst14 = 2.2e+02 / self.fConst0;
		self.fConst15 = 11088.0 / self.fConst0;
		self.fConst16 = 1.0 / (fConst1 * fConst3);
		self.fConst17 = 0.0 - self.fConst16;
	}
	fn instance_init(&mut self, sample_rate: i32) {
		self.instance_constants(sample_rate);
		self.instance_reset_params();
		self.instance_clear();
	}
	fn init(&mut self, sample_rate: i32) {
		DSP_Cowbell3::class_init(sample_rate);
		self.instance_init(sample_rate);
	}
	
	fn build_user_interface(&self, ui_interface: &mut dyn UI<Self::T>) {
		Self::build_user_interface_static(ui_interface);
	}
	
	fn build_user_interface_static(ui_interface: &mut dyn UI<Self::T>) {
		ui_interface.open_vertical_box("main");
		ui_interface.add_num_entry("Trigger", ParamIndex(0), 0.0, 0.0, 1.0, 0.01);
		ui_interface.declare(Some(ParamIndex(1)), "1", "");
		ui_interface.declare(Some(ParamIndex(1)), "export", "Gain");
		ui_interface.declare(Some(ParamIndex(1)), "unit", "dB");
		ui_interface.add_horizontal_slider("Voice_Gain", ParamIndex(1), 0.0, -1e+02, 6.0, 0.1);
		ui_interface.declare(Some(ParamIndex(2)), "2", "");
		ui_interface.declare(Some(ParamIndex(2)), "export", "Pan");
		ui_interface.declare(Some(ParamIndex(2)), "unit", "%");
		ui_interface.add_horizontal_slider("Voice_Pan", ParamIndex(2), 0.0, -1e+02, 1e+02, 0.01);
		ui_interface.declare(Some(ParamIndex(3)), "4", "");
		ui_interface.declare(Some(ParamIndex(3)), "export", "Transpose");
		ui_interface.declare(Some(ParamIndex(3)), "unit", "st");
		ui_interface.add_horizontal_slider("Voice_Transpose", ParamIndex(3), 0.0, -12.0, 12.0, 0.01);
		ui_interface.declare(Some(ParamIndex(4)), "8", "");
		ui_interface.declare(Some(ParamIndex(4)), "export", "Reverb");
		ui_interface.declare(Some(ParamIndex(4)), "unit", "%");
		ui_interface.add_horizontal_slider("Voice_Reverb", ParamIndex(4), 2e+01, 0.0, 1e+02, 0.01);
		ui_interface.add_horizontal_slider("gain", ParamIndex(5), 0.0, 0.0, 1.0, 0.01);
		ui_interface.add_button("gate", ParamIndex(6));
		ui_interface.add_horizontal_slider("key", ParamIndex(7), 36.0, 0.0, 127.0, 1.0);
		ui_interface.close_box();
	}
	
	fn get_param(&self, param: ParamIndex) -> Option<Self::T> {
		match param.0 {
			6 => Some(self.fButton0),
			0 => Some(self.fEntry0),
			5 => Some(self.fHslider0),
			7 => Some(self.fHslider1),
			3 => Some(self.fHslider2),
			2 => Some(self.fHslider3),
			1 => Some(self.fHslider4),
			4 => Some(self.fHslider5),
			_ => None,
		}
	}
	
	fn set_param(&mut self, param: ParamIndex, value: Self::T) {
		match param.0 {
			6 => { self.fButton0 = value }
			0 => { self.fEntry0 = value }
			5 => { self.fHslider0 = value }
			7 => { self.fHslider1 = value }
			3 => { self.fHslider2 = value }
			2 => { self.fHslider3 = value }
			1 => { self.fHslider4 = value }
			4 => { self.fHslider5 = value }
			_ => {}
		}
	}
	
	fn compute(&mut self, count: i32, inputs: &[&[Self::T]], outputs: &mut[&mut[Self::T]]) {
        #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
        if is_x86_feature_detected!("avx2") {
            // Use specialized avx2 version and return
            unsafe { self.compute_x86_or_x86_64_using_avx2(count, inputs, outputs); }
            return;
        }
        #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
        if is_x86_feature_detected!("avx") {
            // Use specialized avx version and return
            unsafe { self.compute_x86_or_x86_64_using_avx(count, inputs, outputs); }
            return;
        }
        #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
        if is_x86_feature_detected!("sse4.1") {
            // Use specialized sse4.1 version and return
            unsafe { self.compute_x86_or_x86_64_using_sse4_1(count, inputs, outputs); }
            return;
        }
        #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
        if is_x86_feature_detected!("sse3") {
            // Use specialized sse3 version and return
            unsafe { self.compute_x86_or_x86_64_using_sse3(count, inputs, outputs); }
            return;
        }
		let (outputs0, outputs1, outputs2) = if let [outputs0, outputs1, outputs2, ..] = outputs {
			let outputs0 = outputs0[..count as usize].iter_mut();
			let outputs1 = outputs1[..count as usize].iter_mut();
			let outputs2 = outputs2[..count as usize].iter_mut();
			(outputs0, outputs1, outputs2)
		} else {
			panic!("wrong number of outputs");
		};
		let mut fSlow0: F32 = self.fButton0;
		let mut iSlow1: i32 = ((fSlow0 > 0.0) as i32);
		let mut iSlow2: i32 = ((iSlow1 > 0) as i32);
		let mut fSlow3: F32 = self.fHslider0;
		let mut fSlow4: F32 = self.fEntry0;
		let mut iSlow5: i32 = ((fSlow4 > 0.0) as i32);
		let mut iSlow6: i32 = (((((fSlow0 == 0.0) as i32)) > 0) as i32);
		let mut fSlow7: F32 = ((iSlow1) as F32);
		let mut fSlow8: F32 = F32::powf(2.0, 0.083333336 * (self.fHslider2 + self.fHslider1 + -79.0));
		let mut fSlow9: F32 = 15.996094 * (0.1 * (1.0 - 0.008333334 * (17.31234 * F32::log(fSlow8, std::f32::consts::E) + 48.0)) + 128.0);
		let mut iSlow10: i32 = ((fSlow9) as i32);
		let mut fSlow11: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iSlow10) as usize] };
		let mut fSlow12: F32 = fSlow11 + (fSlow9 - ((iSlow10) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iSlow10, 1)) as usize] } - fSlow11);
		let mut fSlow13: F32 = self.fConst13 * fSlow8;
		let mut fSlow14: F32 = self.fConst14 * fSlow8;
		let mut fSlow15: F32 = self.fConst15 * fSlow8;
		let mut fSlow16: F32 = 0.01 * self.fHslider3;
		let mut fSlow17: F32 = F32::powf(1e+01, 0.05 * F32::max(-1e+02, self.fHslider4 + -2.0));
		let mut fSlow18: F32 = fSlow17 * F32::min(1.0, 1.0 - fSlow16);
		let mut fSlow19: F32 = fSlow17 * F32::min(1.0, fSlow16 + 1.0);
		let mut fSlow20: F32 = 0.01 * self.fHslider5 * fSlow17;
		let zipped_iterators = outputs0.zip(outputs1).zip(outputs2);
		for ((output0, output1), output2) in zipped_iterators {
			self.fVec0[0] = fSlow0;
			let mut iTemp1: i32 = i32::wrapping_sub(1, ((fSlow0 > self.fVec0[1]) as i32));
			self.fRec5[0] = if (iSlow5 as i32 != 0) { fSlow4 } else { self.fRec5[1] };
			let mut fTemp2: F32 = F32::max(0.0, F32::min(127.0, 0.14285715 * (106.0 * (1.0 - DSP_Cowbell3_faustpower2_f(1.0 - F32::max(fSlow3, self.fRec5[0]))) + -99.0) + 85.0));
			let mut fTemp3: F32 = 32.0 * F32::min(1.0, 0.05 * fTemp2) * (fTemp2 + 28.0);
			self.fRec4[0] = if (iTemp1 as i32 != 0) { fTemp3 } else { self.fRec4[1] };
			let mut fTemp4: F32 = F32::max(5076.0, self.fRec4[0]);
			self.fRec6[0] = if (iTemp1 as i32 != 0) { fTemp3 + 4064.0 } else { self.fRec6[1] };
			let mut fTemp5: F32 = self.fRec6[0] - fTemp4;
			self.fRec8[0] = if (iTemp1 as i32 != 0) { 0.0 } else { self.fRec8[1] };
			let mut fTemp6: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp5) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 88.0) as i32)) as usize] } * if (((fTemp5 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp4)) + 2.0) } else { 0.96 }))));
			self.fRec9[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp6, self.fRec9[1] + 1.0) };
			let mut iTemp7: i32 = ((self.fRec9[0] < fTemp6) as i32);
			let mut fTemp8: F32 = self.fRec9[0] / fTemp6;
			self.fRec3[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec9[0] < (self.fConst5 + fTemp6)) as i32) as i32 != 0) { if (iTemp7 as i32 != 0) { if (((self.fRec9[0] < 0.0) as i32) as i32 != 0) { fTemp4 } else { if (iTemp7 as i32 != 0) { fTemp4 + fTemp5 * if (((self.fRec6[0] > fTemp4) as i32) as i32 != 0) { F32::powf(fTemp8, 0.33333334) } else { fTemp8 } } else { self.fRec6[0] } } } else { self.fRec6[0] } } else { self.fRec6[0] } } else { self.fRec3[1] };
			let mut fTemp9: F32 = self.fRec4[0] - self.fRec3[0];
			let mut fTemp10: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp9) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 7e+01) as i32)) as usize] } * if (((fTemp9 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec3[0])) + 2.0) } else { 0.96 }))));
			self.fRec2[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp10, self.fRec2[1] + 1.0) };
			let mut fTemp11: F32 = self.fRec2[0] / fTemp10;
			let mut fTemp12: F32 = if (((self.fRec2[0] < 0.0) as i32) as i32 != 0) { self.fRec3[0] } else { if (((self.fRec2[0] < fTemp10) as i32) as i32 != 0) { self.fRec3[0] + fTemp9 * if (((self.fRec4[0] > self.fRec3[0]) as i32) as i32 != 0) { F32::powf(fTemp11, 0.33333334) } else { fTemp11 } } else { self.fRec4[0] } };
			let mut iTemp13: i32 = ((fTemp12) as i32);
			let mut fTemp14: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp13) as usize] };
			self.fRec13[0] = if (iTemp1 as i32 != 0) { 6944.0 } else { self.fRec13[1] };
			self.fRec14[0] = if (iTemp1 as i32 != 0) { 6.72e+03 } else { self.fRec14[1] };
			let mut fTemp15: F32 = self.fRec14[0] - self.fRec13[0];
			let mut fTemp16: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp15) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 68.0) as i32)) as usize] } * if (((fTemp15 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec13[0])) + 2.0) } else { 0.96 }))));
			self.fRec15[0] = if (iTemp1 as i32 != 0) { 2976.0 } else { self.fRec15[1] };
			let mut fTemp17: F32 = F32::max(5076.0, self.fRec15[0]);
			let mut fTemp18: F32 = self.fRec13[0] - fTemp17;
			let mut fTemp19: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp18) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 94.0) as i32)) as usize] } * if (((fTemp18 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp17)) + 2.0) } else { 0.96 }))));
			let mut fTemp20: F32 = fTemp19 + fTemp16;
			let mut fTemp21: F32 = self.fRec15[0] - self.fRec14[0];
			let mut fTemp22: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp21) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 24.0) as i32)) as usize] } * if (((fTemp21 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec14[0])) + 2.0) } else { 0.96 }))));
			let mut fTemp23: F32 = fTemp20 + fTemp22;
			self.fRec16[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp23, self.fRec16[1] + 1.0) };
			let mut iTemp24: i32 = ((self.fRec16[0] < fTemp20) as i32);
			let mut fTemp25: F32 = (self.fRec16[0] - fTemp20) / fTemp22;
			let mut iTemp26: i32 = ((self.fRec16[0] < fTemp19) as i32);
			let mut fTemp27: F32 = (self.fRec16[0] - fTemp19) / fTemp16;
			let mut fTemp28: F32 = self.fRec16[0] / fTemp19;
			self.fRec12[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp24 as i32 != 0) { if (iTemp26 as i32 != 0) { if (((self.fRec16[0] < 0.0) as i32) as i32 != 0) { fTemp17 } else { if (iTemp26 as i32 != 0) { fTemp17 + fTemp18 * if (((self.fRec13[0] > fTemp17) as i32) as i32 != 0) { F32::powf(fTemp28, 0.33333334) } else { fTemp28 } } else { self.fRec13[0] } } } else { if (iTemp24 as i32 != 0) { self.fRec13[0] + fTemp15 * if (((self.fRec14[0] > self.fRec13[0]) as i32) as i32 != 0) { F32::powf(fTemp27, 0.33333334) } else { fTemp27 } } else { self.fRec14[0] } } } else { if (((self.fRec16[0] < fTemp23) as i32) as i32 != 0) { self.fRec14[0] + fTemp21 * if (((self.fRec15[0] > self.fRec14[0]) as i32) as i32 != 0) { F32::powf(fTemp25, 0.33333334) } else { fTemp25 } } else { self.fRec15[0] } } } else { self.fRec12[1] };
			let mut fTemp29: F32 = self.fRec15[0] - self.fRec12[0];
			let mut fTemp30: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp29) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 55.0) as i32)) as usize] } * if (((fTemp29 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec12[0])) + 2.0) } else { 0.96 }))));
			self.fRec11[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp30, self.fRec11[1] + 1.0) };
			let mut fTemp31: F32 = self.fRec11[0] / fTemp30;
			let mut fTemp32: F32 = if (((self.fRec11[0] < 0.0) as i32) as i32 != 0) { self.fRec12[0] } else { if (((self.fRec11[0] < fTemp30) as i32) as i32 != 0) { self.fRec12[0] + fTemp29 * if (((self.fRec15[0] > self.fRec12[0]) as i32) as i32 != 0) { F32::powf(fTemp31, 0.33333334) } else { fTemp31 } } else { self.fRec15[0] } };
			let mut iTemp33: i32 = ((fTemp32) as i32);
			let mut fTemp34: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp33) as usize] };
			self.iRec21[0] = if (iTemp1 as i32 != 0) { self.iConst9 } else { self.iRec21[1] };
			self.iRec22[0] = if (iTemp1 as i32 != 0) { self.iConst10 } else { self.iRec22[1] };
			let mut iTemp35: i32 = i32::wrapping_sub(self.iRec22[0], self.iRec21[0]);
			let mut fTemp36: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp35)) as F32) / self.fConst8));
			let mut iTemp37: i32 = i32::wrapping_sub(self.iRec21[0], self.iRec22[0]);
			let mut fTemp38: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp37)) as F32) / self.fConst12));
			let mut fTemp39: F32 = fTemp38 + fTemp36;
			self.fRec23[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp39 + 1.0, self.fRec23[1] + 1.0) };
			let mut iTemp40: i32 = ((self.fRec23[0] < fTemp39) as i32);
			let mut fTemp41: F32 = ((self.iRec22[0]) as F32);
			let mut iTemp42: i32 = ((self.fRec23[0] < fTemp38) as i32);
			let mut fTemp43: F32 = (self.fRec23[0] - fTemp38) / fTemp36;
			let mut fTemp44: F32 = ((self.iRec21[0]) as F32);
			let mut fTemp45: F32 = self.fRec23[0] / fTemp38;
			self.fRec20[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp40 as i32 != 0) { if (iTemp42 as i32 != 0) { if (((self.fRec23[0] < 0.0) as i32) as i32 != 0) { fTemp41 } else { if (iTemp42 as i32 != 0) { fTemp41 + ((iTemp37) as F32) * if (((self.iRec21[0] > self.iRec22[0]) as i32) as i32 != 0) { F32::powf(fTemp45, 0.33333334) } else { fTemp45 } } else { fTemp44 } } } else { if (iTemp40 as i32 != 0) { fTemp44 + ((iTemp35) as F32) * if (((self.iRec22[0] > self.iRec21[0]) as i32) as i32 != 0) { F32::powf(fTemp43, 0.33333334) } else { fTemp43 } } else { fTemp41 } } } else { fTemp41 } } else { self.fRec20[1] };
			let mut fTemp46: F32 = fTemp41 - self.fRec20[0];
			let mut fTemp47: F32 = F32::max(1.0, self.fConst11 * (F32::abs(fTemp46) / self.fConst7));
			self.fRec19[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp47, self.fRec19[1] + 1.0) };
			let mut fTemp48: F32 = self.fRec19[0] / fTemp47;
			let mut fTemp49: F32 = 15.996094 * (0.4 * if (((self.fRec19[0] < 0.0) as i32) as i32 != 0) { self.fRec20[0] } else { if (((self.fRec19[0] < fTemp47) as i32) as i32 != 0) { self.fRec20[0] + fTemp46 * if (((fTemp41 > self.fRec20[0]) as i32) as i32 != 0) { F32::powf(fTemp48, 0.33333334) } else { fTemp48 } } else { fTemp41 } } + 128.0);
			let mut iTemp50: i32 = ((fTemp49) as i32);
			let mut fTemp51: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iTemp50) as usize] };
			let mut fTemp52: F32 = fSlow12 * (fTemp51 + (fTemp49 - ((iTemp50) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iTemp50, 1)) as usize] } - fTemp51));
			let mut fTemp53: F32 = self.fRec17[1] + fSlow13 * fTemp52;
			self.fRec17[0] = fTemp53 - F32::floor(fTemp53);
			self.fRec26[0] = if (iTemp1 as i32 != 0) { 3872.0 } else { self.fRec26[1] };
			let mut fTemp54: F32 = F32::max(5076.0, self.fRec26[0]);
			self.fRec27[0] = if (iTemp1 as i32 != 0) { 7936.0 } else { self.fRec27[1] };
			let mut fTemp55: F32 = self.fRec27[0] - fTemp54;
			let mut fTemp56: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp55) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 71.0) as i32)) as usize] } * if (((fTemp55 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp54)) + 2.0) } else { 0.96 }))));
			self.fRec28[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp56, self.fRec28[1] + 1.0) };
			let mut iTemp57: i32 = ((self.fRec28[0] < fTemp56) as i32);
			let mut fTemp58: F32 = self.fRec28[0] / fTemp56;
			self.fRec25[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec28[0] < (self.fConst5 + fTemp56)) as i32) as i32 != 0) { if (iTemp57 as i32 != 0) { if (((self.fRec28[0] < 0.0) as i32) as i32 != 0) { fTemp54 } else { if (iTemp57 as i32 != 0) { fTemp54 + fTemp55 * if (((self.fRec27[0] > fTemp54) as i32) as i32 != 0) { F32::powf(fTemp58, 0.33333334) } else { fTemp58 } } else { self.fRec27[0] } } } else { self.fRec27[0] } } else { self.fRec27[0] } } else { self.fRec25[1] };
			let mut fTemp59: F32 = self.fRec26[0] - self.fRec25[0];
			let mut fTemp60: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp59) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 51.0) as i32)) as usize] } * if (((fTemp59 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec25[0])) + 2.0) } else { 0.96 }))));
			self.fRec24[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp60, self.fRec24[1] + 1.0) };
			let mut fTemp61: F32 = self.fRec24[0] / fTemp60;
			let mut fTemp62: F32 = if (((self.fRec24[0] < 0.0) as i32) as i32 != 0) { self.fRec25[0] } else { if (((self.fRec24[0] < fTemp60) as i32) as i32 != 0) { self.fRec25[0] + fTemp59 * if (((self.fRec26[0] > self.fRec25[0]) as i32) as i32 != 0) { F32::powf(fTemp61, 0.33333334) } else { fTemp61 } } else { self.fRec26[0] } };
			let mut iTemp63: i32 = ((fTemp62) as i32);
			let mut fTemp64: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp63) as usize] };
			let mut fTemp65: F32 = self.fRec29[1] + fSlow14 * fTemp52;
			self.fRec29[0] = fTemp65 - F32::floor(fTemp65);
			let mut fTemp66: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec29[0] + 1.024e+04) as i32) % 1024) as usize] };
			self.fRec33[0] = if (iTemp1 as i32 != 0) { 3.04e+03 } else { self.fRec33[1] };
			let mut fTemp67: F32 = F32::max(5076.0, self.fRec33[0]);
			self.fRec34[0] = if (iTemp1 as i32 != 0) { 7104.0 } else { self.fRec34[1] };
			let mut fTemp68: F32 = self.fRec34[0] - fTemp67;
			let mut fTemp69: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp68) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 67.0) as i32)) as usize] } * if (((fTemp68 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp67)) + 2.0) } else { 0.96 }))));
			self.fRec35[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp69, self.fRec35[1] + 1.0) };
			let mut iTemp70: i32 = ((self.fRec35[0] < fTemp69) as i32);
			let mut fTemp71: F32 = self.fRec35[0] / fTemp69;
			self.fRec32[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec35[0] < (self.fConst5 + fTemp69)) as i32) as i32 != 0) { if (iTemp70 as i32 != 0) { if (((self.fRec35[0] < 0.0) as i32) as i32 != 0) { fTemp67 } else { if (iTemp70 as i32 != 0) { fTemp67 + fTemp68 * if (((self.fRec34[0] > fTemp67) as i32) as i32 != 0) { F32::powf(fTemp71, 0.33333334) } else { fTemp71 } } else { self.fRec34[0] } } } else { self.fRec34[0] } } else { self.fRec34[0] } } else { self.fRec32[1] };
			let mut fTemp72: F32 = self.fRec33[0] - self.fRec32[0];
			let mut fTemp73: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp72) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 4e+01) as i32)) as usize] } * if (((fTemp72 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec32[0])) + 2.0) } else { 0.96 }))));
			self.fRec31[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp73, self.fRec31[1] + 1.0) };
			let mut fTemp74: F32 = self.fRec31[0] / fTemp73;
			let mut fTemp75: F32 = if (((self.fRec31[0] < 0.0) as i32) as i32 != 0) { self.fRec32[0] } else { if (((self.fRec31[0] < fTemp73) as i32) as i32 != 0) { self.fRec32[0] + fTemp72 * if (((self.fRec33[0] > self.fRec32[0]) as i32) as i32 != 0) { F32::powf(fTemp74, 0.33333334) } else { fTemp74 } } else { self.fRec33[0] } };
			let mut iTemp76: i32 = ((fTemp75) as i32);
			let mut fTemp77: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp76) as usize] };
			let mut fRec30: F32 = 0.115 * fTemp66 * (fTemp77 + (fTemp75 - ((iTemp76) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp76, 1)) as usize] } - fTemp77));
			let mut fTemp78: F32 = self.fRec36[1] + fSlow15 * fTemp52;
			self.fRec36[0] = fTemp78 - F32::floor(fTemp78);
			let mut fTemp79: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * (self.fRec36[0] + 17.391304 * (fRec30 + 0.115 * (fTemp66 * (fTemp64 + (fTemp62 - ((iTemp63) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp63, 1)) as usize] } - fTemp64)) + unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec17[0] + 1.024e+04) as i32) % 1024) as usize] } * (fTemp34 + (fTemp32 - ((iTemp33) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp33, 1)) as usize] } - fTemp34)))) + 1e+01)) as i32) % 1024) as usize] } * (fTemp14 + (fTemp12 - ((iTemp13) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp13, 1)) as usize] } - fTemp14));
			self.fVec2[0] = fTemp79;
			self.fRec0[0] = 0.115 * (self.fConst16 * fTemp79 + self.fConst17 * self.fVec2[1]) - self.fConst4 * self.fRec0[1];
			*output0 = fSlow18 * self.fRec0[0];
			*output1 = fSlow19 * self.fRec0[0];
			*output2 = fSlow20 * self.fRec0[0];
			self.fVec0[1] = self.fVec0[0];
			self.fRec5[1] = self.fRec5[0];
			self.fRec4[1] = self.fRec4[0];
			self.fRec6[1] = self.fRec6[0];
			self.fRec8[1] = self.fRec8[0];
			self.fRec9[1] = self.fRec9[0];
			self.fRec3[1] = self.fRec3[0];
			self.fRec2[1] = self.fRec2[0];
			self.fRec13[1] = self.fRec13[0];
			self.fRec14[1] = self.fRec14[0];
			self.fRec15[1] = self.fRec15[0];
			self.fRec16[1] = self.fRec16[0];
			self.fRec12[1] = self.fRec12[0];
			self.fRec11[1] = self.fRec11[0];
			self.iRec21[1] = self.iRec21[0];
			self.iRec22[1] = self.iRec22[0];
			self.fRec23[1] = self.fRec23[0];
			self.fRec20[1] = self.fRec20[0];
			self.fRec19[1] = self.fRec19[0];
			self.fRec17[1] = self.fRec17[0];
			self.fRec26[1] = self.fRec26[0];
			self.fRec27[1] = self.fRec27[0];
			self.fRec28[1] = self.fRec28[0];
			self.fRec25[1] = self.fRec25[0];
			self.fRec24[1] = self.fRec24[0];
			self.fRec29[1] = self.fRec29[0];
			self.fRec33[1] = self.fRec33[0];
			self.fRec34[1] = self.fRec34[0];
			self.fRec35[1] = self.fRec35[0];
			self.fRec32[1] = self.fRec32[0];
			self.fRec31[1] = self.fRec31[0];
			self.fRec36[1] = self.fRec36[0];
			self.fVec2[1] = self.fVec2[0];
			self.fRec0[1] = self.fRec0[0];
		}
	}

}

impl DSP_Cowbell3 {
    /*
       This function was copied from above and
       tweaked to enable auto-vectorization using sse3
    */
    #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
    #[target_feature(enable = "sse3")]
	unsafe fn compute_x86_or_x86_64_using_sse3(&mut self, count: i32, inputs: &[&[<DSP_Cowbell3 as FaustDsp>::T]], outputs: &mut[&mut[<DSP_Cowbell3 as FaustDsp>::T]]) {
		let (outputs0, outputs1, outputs2) = if let [outputs0, outputs1, outputs2, ..] = outputs {
			let outputs0 = outputs0[..count as usize].iter_mut();
			let outputs1 = outputs1[..count as usize].iter_mut();
			let outputs2 = outputs2[..count as usize].iter_mut();
			(outputs0, outputs1, outputs2)
		} else {
			panic!("wrong number of outputs");
		};
		let mut fSlow0: F32 = self.fButton0;
		let mut iSlow1: i32 = ((fSlow0 > 0.0) as i32);
		let mut iSlow2: i32 = ((iSlow1 > 0) as i32);
		let mut fSlow3: F32 = self.fHslider0;
		let mut fSlow4: F32 = self.fEntry0;
		let mut iSlow5: i32 = ((fSlow4 > 0.0) as i32);
		let mut iSlow6: i32 = (((((fSlow0 == 0.0) as i32)) > 0) as i32);
		let mut fSlow7: F32 = ((iSlow1) as F32);
		let mut fSlow8: F32 = F32::powf(2.0, 0.083333336 * (self.fHslider2 + self.fHslider1 + -79.0));
		let mut fSlow9: F32 = 15.996094 * (0.1 * (1.0 - 0.008333334 * (17.31234 * F32::log(fSlow8, std::f32::consts::E) + 48.0)) + 128.0);
		let mut iSlow10: i32 = ((fSlow9) as i32);
		let mut fSlow11: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iSlow10) as usize] };
		let mut fSlow12: F32 = fSlow11 + (fSlow9 - ((iSlow10) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iSlow10, 1)) as usize] } - fSlow11);
		let mut fSlow13: F32 = self.fConst13 * fSlow8;
		let mut fSlow14: F32 = self.fConst14 * fSlow8;
		let mut fSlow15: F32 = self.fConst15 * fSlow8;
		let mut fSlow16: F32 = 0.01 * self.fHslider3;
		let mut fSlow17: F32 = F32::powf(1e+01, 0.05 * F32::max(-1e+02, self.fHslider4 + -2.0));
		let mut fSlow18: F32 = fSlow17 * F32::min(1.0, 1.0 - fSlow16);
		let mut fSlow19: F32 = fSlow17 * F32::min(1.0, fSlow16 + 1.0);
		let mut fSlow20: F32 = 0.01 * self.fHslider5 * fSlow17;
		let zipped_iterators = outputs0.zip(outputs1).zip(outputs2);
		for ((output0, output1), output2) in zipped_iterators {
			self.fVec0[0] = fSlow0;
			let mut iTemp1: i32 = i32::wrapping_sub(1, ((fSlow0 > self.fVec0[1]) as i32));
			self.fRec5[0] = if (iSlow5 as i32 != 0) { fSlow4 } else { self.fRec5[1] };
			let mut fTemp2: F32 = F32::max(0.0, F32::min(127.0, 0.14285715 * (106.0 * (1.0 - DSP_Cowbell3_faustpower2_f(1.0 - F32::max(fSlow3, self.fRec5[0]))) + -99.0) + 85.0));
			let mut fTemp3: F32 = 32.0 * F32::min(1.0, 0.05 * fTemp2) * (fTemp2 + 28.0);
			self.fRec4[0] = if (iTemp1 as i32 != 0) { fTemp3 } else { self.fRec4[1] };
			let mut fTemp4: F32 = F32::max(5076.0, self.fRec4[0]);
			self.fRec6[0] = if (iTemp1 as i32 != 0) { fTemp3 + 4064.0 } else { self.fRec6[1] };
			let mut fTemp5: F32 = self.fRec6[0] - fTemp4;
			self.fRec8[0] = if (iTemp1 as i32 != 0) { 0.0 } else { self.fRec8[1] };
			let mut fTemp6: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp5) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 88.0) as i32)) as usize] } * if (((fTemp5 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp4)) + 2.0) } else { 0.96 }))));
			self.fRec9[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp6, self.fRec9[1] + 1.0) };
			let mut iTemp7: i32 = ((self.fRec9[0] < fTemp6) as i32);
			let mut fTemp8: F32 = self.fRec9[0] / fTemp6;
			self.fRec3[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec9[0] < (self.fConst5 + fTemp6)) as i32) as i32 != 0) { if (iTemp7 as i32 != 0) { if (((self.fRec9[0] < 0.0) as i32) as i32 != 0) { fTemp4 } else { if (iTemp7 as i32 != 0) { fTemp4 + fTemp5 * if (((self.fRec6[0] > fTemp4) as i32) as i32 != 0) { F32::powf(fTemp8, 0.33333334) } else { fTemp8 } } else { self.fRec6[0] } } } else { self.fRec6[0] } } else { self.fRec6[0] } } else { self.fRec3[1] };
			let mut fTemp9: F32 = self.fRec4[0] - self.fRec3[0];
			let mut fTemp10: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp9) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 7e+01) as i32)) as usize] } * if (((fTemp9 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec3[0])) + 2.0) } else { 0.96 }))));
			self.fRec2[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp10, self.fRec2[1] + 1.0) };
			let mut fTemp11: F32 = self.fRec2[0] / fTemp10;
			let mut fTemp12: F32 = if (((self.fRec2[0] < 0.0) as i32) as i32 != 0) { self.fRec3[0] } else { if (((self.fRec2[0] < fTemp10) as i32) as i32 != 0) { self.fRec3[0] + fTemp9 * if (((self.fRec4[0] > self.fRec3[0]) as i32) as i32 != 0) { F32::powf(fTemp11, 0.33333334) } else { fTemp11 } } else { self.fRec4[0] } };
			let mut iTemp13: i32 = ((fTemp12) as i32);
			let mut fTemp14: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp13) as usize] };
			self.fRec13[0] = if (iTemp1 as i32 != 0) { 6944.0 } else { self.fRec13[1] };
			self.fRec14[0] = if (iTemp1 as i32 != 0) { 6.72e+03 } else { self.fRec14[1] };
			let mut fTemp15: F32 = self.fRec14[0] - self.fRec13[0];
			let mut fTemp16: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp15) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 68.0) as i32)) as usize] } * if (((fTemp15 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec13[0])) + 2.0) } else { 0.96 }))));
			self.fRec15[0] = if (iTemp1 as i32 != 0) { 2976.0 } else { self.fRec15[1] };
			let mut fTemp17: F32 = F32::max(5076.0, self.fRec15[0]);
			let mut fTemp18: F32 = self.fRec13[0] - fTemp17;
			let mut fTemp19: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp18) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 94.0) as i32)) as usize] } * if (((fTemp18 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp17)) + 2.0) } else { 0.96 }))));
			let mut fTemp20: F32 = fTemp19 + fTemp16;
			let mut fTemp21: F32 = self.fRec15[0] - self.fRec14[0];
			let mut fTemp22: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp21) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 24.0) as i32)) as usize] } * if (((fTemp21 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec14[0])) + 2.0) } else { 0.96 }))));
			let mut fTemp23: F32 = fTemp20 + fTemp22;
			self.fRec16[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp23, self.fRec16[1] + 1.0) };
			let mut iTemp24: i32 = ((self.fRec16[0] < fTemp20) as i32);
			let mut fTemp25: F32 = (self.fRec16[0] - fTemp20) / fTemp22;
			let mut iTemp26: i32 = ((self.fRec16[0] < fTemp19) as i32);
			let mut fTemp27: F32 = (self.fRec16[0] - fTemp19) / fTemp16;
			let mut fTemp28: F32 = self.fRec16[0] / fTemp19;
			self.fRec12[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp24 as i32 != 0) { if (iTemp26 as i32 != 0) { if (((self.fRec16[0] < 0.0) as i32) as i32 != 0) { fTemp17 } else { if (iTemp26 as i32 != 0) { fTemp17 + fTemp18 * if (((self.fRec13[0] > fTemp17) as i32) as i32 != 0) { F32::powf(fTemp28, 0.33333334) } else { fTemp28 } } else { self.fRec13[0] } } } else { if (iTemp24 as i32 != 0) { self.fRec13[0] + fTemp15 * if (((self.fRec14[0] > self.fRec13[0]) as i32) as i32 != 0) { F32::powf(fTemp27, 0.33333334) } else { fTemp27 } } else { self.fRec14[0] } } } else { if (((self.fRec16[0] < fTemp23) as i32) as i32 != 0) { self.fRec14[0] + fTemp21 * if (((self.fRec15[0] > self.fRec14[0]) as i32) as i32 != 0) { F32::powf(fTemp25, 0.33333334) } else { fTemp25 } } else { self.fRec15[0] } } } else { self.fRec12[1] };
			let mut fTemp29: F32 = self.fRec15[0] - self.fRec12[0];
			let mut fTemp30: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp29) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 55.0) as i32)) as usize] } * if (((fTemp29 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec12[0])) + 2.0) } else { 0.96 }))));
			self.fRec11[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp30, self.fRec11[1] + 1.0) };
			let mut fTemp31: F32 = self.fRec11[0] / fTemp30;
			let mut fTemp32: F32 = if (((self.fRec11[0] < 0.0) as i32) as i32 != 0) { self.fRec12[0] } else { if (((self.fRec11[0] < fTemp30) as i32) as i32 != 0) { self.fRec12[0] + fTemp29 * if (((self.fRec15[0] > self.fRec12[0]) as i32) as i32 != 0) { F32::powf(fTemp31, 0.33333334) } else { fTemp31 } } else { self.fRec15[0] } };
			let mut iTemp33: i32 = ((fTemp32) as i32);
			let mut fTemp34: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp33) as usize] };
			self.iRec21[0] = if (iTemp1 as i32 != 0) { self.iConst9 } else { self.iRec21[1] };
			self.iRec22[0] = if (iTemp1 as i32 != 0) { self.iConst10 } else { self.iRec22[1] };
			let mut iTemp35: i32 = i32::wrapping_sub(self.iRec22[0], self.iRec21[0]);
			let mut fTemp36: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp35)) as F32) / self.fConst8));
			let mut iTemp37: i32 = i32::wrapping_sub(self.iRec21[0], self.iRec22[0]);
			let mut fTemp38: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp37)) as F32) / self.fConst12));
			let mut fTemp39: F32 = fTemp38 + fTemp36;
			self.fRec23[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp39 + 1.0, self.fRec23[1] + 1.0) };
			let mut iTemp40: i32 = ((self.fRec23[0] < fTemp39) as i32);
			let mut fTemp41: F32 = ((self.iRec22[0]) as F32);
			let mut iTemp42: i32 = ((self.fRec23[0] < fTemp38) as i32);
			let mut fTemp43: F32 = (self.fRec23[0] - fTemp38) / fTemp36;
			let mut fTemp44: F32 = ((self.iRec21[0]) as F32);
			let mut fTemp45: F32 = self.fRec23[0] / fTemp38;
			self.fRec20[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp40 as i32 != 0) { if (iTemp42 as i32 != 0) { if (((self.fRec23[0] < 0.0) as i32) as i32 != 0) { fTemp41 } else { if (iTemp42 as i32 != 0) { fTemp41 + ((iTemp37) as F32) * if (((self.iRec21[0] > self.iRec22[0]) as i32) as i32 != 0) { F32::powf(fTemp45, 0.33333334) } else { fTemp45 } } else { fTemp44 } } } else { if (iTemp40 as i32 != 0) { fTemp44 + ((iTemp35) as F32) * if (((self.iRec22[0] > self.iRec21[0]) as i32) as i32 != 0) { F32::powf(fTemp43, 0.33333334) } else { fTemp43 } } else { fTemp41 } } } else { fTemp41 } } else { self.fRec20[1] };
			let mut fTemp46: F32 = fTemp41 - self.fRec20[0];
			let mut fTemp47: F32 = F32::max(1.0, self.fConst11 * (F32::abs(fTemp46) / self.fConst7));
			self.fRec19[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp47, self.fRec19[1] + 1.0) };
			let mut fTemp48: F32 = self.fRec19[0] / fTemp47;
			let mut fTemp49: F32 = 15.996094 * (0.4 * if (((self.fRec19[0] < 0.0) as i32) as i32 != 0) { self.fRec20[0] } else { if (((self.fRec19[0] < fTemp47) as i32) as i32 != 0) { self.fRec20[0] + fTemp46 * if (((fTemp41 > self.fRec20[0]) as i32) as i32 != 0) { F32::powf(fTemp48, 0.33333334) } else { fTemp48 } } else { fTemp41 } } + 128.0);
			let mut iTemp50: i32 = ((fTemp49) as i32);
			let mut fTemp51: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iTemp50) as usize] };
			let mut fTemp52: F32 = fSlow12 * (fTemp51 + (fTemp49 - ((iTemp50) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iTemp50, 1)) as usize] } - fTemp51));
			let mut fTemp53: F32 = self.fRec17[1] + fSlow13 * fTemp52;
			self.fRec17[0] = fTemp53 - F32::floor(fTemp53);
			self.fRec26[0] = if (iTemp1 as i32 != 0) { 3872.0 } else { self.fRec26[1] };
			let mut fTemp54: F32 = F32::max(5076.0, self.fRec26[0]);
			self.fRec27[0] = if (iTemp1 as i32 != 0) { 7936.0 } else { self.fRec27[1] };
			let mut fTemp55: F32 = self.fRec27[0] - fTemp54;
			let mut fTemp56: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp55) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 71.0) as i32)) as usize] } * if (((fTemp55 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp54)) + 2.0) } else { 0.96 }))));
			self.fRec28[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp56, self.fRec28[1] + 1.0) };
			let mut iTemp57: i32 = ((self.fRec28[0] < fTemp56) as i32);
			let mut fTemp58: F32 = self.fRec28[0] / fTemp56;
			self.fRec25[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec28[0] < (self.fConst5 + fTemp56)) as i32) as i32 != 0) { if (iTemp57 as i32 != 0) { if (((self.fRec28[0] < 0.0) as i32) as i32 != 0) { fTemp54 } else { if (iTemp57 as i32 != 0) { fTemp54 + fTemp55 * if (((self.fRec27[0] > fTemp54) as i32) as i32 != 0) { F32::powf(fTemp58, 0.33333334) } else { fTemp58 } } else { self.fRec27[0] } } } else { self.fRec27[0] } } else { self.fRec27[0] } } else { self.fRec25[1] };
			let mut fTemp59: F32 = self.fRec26[0] - self.fRec25[0];
			let mut fTemp60: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp59) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 51.0) as i32)) as usize] } * if (((fTemp59 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec25[0])) + 2.0) } else { 0.96 }))));
			self.fRec24[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp60, self.fRec24[1] + 1.0) };
			let mut fTemp61: F32 = self.fRec24[0] / fTemp60;
			let mut fTemp62: F32 = if (((self.fRec24[0] < 0.0) as i32) as i32 != 0) { self.fRec25[0] } else { if (((self.fRec24[0] < fTemp60) as i32) as i32 != 0) { self.fRec25[0] + fTemp59 * if (((self.fRec26[0] > self.fRec25[0]) as i32) as i32 != 0) { F32::powf(fTemp61, 0.33333334) } else { fTemp61 } } else { self.fRec26[0] } };
			let mut iTemp63: i32 = ((fTemp62) as i32);
			let mut fTemp64: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp63) as usize] };
			let mut fTemp65: F32 = self.fRec29[1] + fSlow14 * fTemp52;
			self.fRec29[0] = fTemp65 - F32::floor(fTemp65);
			let mut fTemp66: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec29[0] + 1.024e+04) as i32) % 1024) as usize] };
			self.fRec33[0] = if (iTemp1 as i32 != 0) { 3.04e+03 } else { self.fRec33[1] };
			let mut fTemp67: F32 = F32::max(5076.0, self.fRec33[0]);
			self.fRec34[0] = if (iTemp1 as i32 != 0) { 7104.0 } else { self.fRec34[1] };
			let mut fTemp68: F32 = self.fRec34[0] - fTemp67;
			let mut fTemp69: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp68) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 67.0) as i32)) as usize] } * if (((fTemp68 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp67)) + 2.0) } else { 0.96 }))));
			self.fRec35[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp69, self.fRec35[1] + 1.0) };
			let mut iTemp70: i32 = ((self.fRec35[0] < fTemp69) as i32);
			let mut fTemp71: F32 = self.fRec35[0] / fTemp69;
			self.fRec32[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec35[0] < (self.fConst5 + fTemp69)) as i32) as i32 != 0) { if (iTemp70 as i32 != 0) { if (((self.fRec35[0] < 0.0) as i32) as i32 != 0) { fTemp67 } else { if (iTemp70 as i32 != 0) { fTemp67 + fTemp68 * if (((self.fRec34[0] > fTemp67) as i32) as i32 != 0) { F32::powf(fTemp71, 0.33333334) } else { fTemp71 } } else { self.fRec34[0] } } } else { self.fRec34[0] } } else { self.fRec34[0] } } else { self.fRec32[1] };
			let mut fTemp72: F32 = self.fRec33[0] - self.fRec32[0];
			let mut fTemp73: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp72) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 4e+01) as i32)) as usize] } * if (((fTemp72 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec32[0])) + 2.0) } else { 0.96 }))));
			self.fRec31[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp73, self.fRec31[1] + 1.0) };
			let mut fTemp74: F32 = self.fRec31[0] / fTemp73;
			let mut fTemp75: F32 = if (((self.fRec31[0] < 0.0) as i32) as i32 != 0) { self.fRec32[0] } else { if (((self.fRec31[0] < fTemp73) as i32) as i32 != 0) { self.fRec32[0] + fTemp72 * if (((self.fRec33[0] > self.fRec32[0]) as i32) as i32 != 0) { F32::powf(fTemp74, 0.33333334) } else { fTemp74 } } else { self.fRec33[0] } };
			let mut iTemp76: i32 = ((fTemp75) as i32);
			let mut fTemp77: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp76) as usize] };
			let mut fRec30: F32 = 0.115 * fTemp66 * (fTemp77 + (fTemp75 - ((iTemp76) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp76, 1)) as usize] } - fTemp77));
			let mut fTemp78: F32 = self.fRec36[1] + fSlow15 * fTemp52;
			self.fRec36[0] = fTemp78 - F32::floor(fTemp78);
			let mut fTemp79: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * (self.fRec36[0] + 17.391304 * (fRec30 + 0.115 * (fTemp66 * (fTemp64 + (fTemp62 - ((iTemp63) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp63, 1)) as usize] } - fTemp64)) + unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec17[0] + 1.024e+04) as i32) % 1024) as usize] } * (fTemp34 + (fTemp32 - ((iTemp33) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp33, 1)) as usize] } - fTemp34)))) + 1e+01)) as i32) % 1024) as usize] } * (fTemp14 + (fTemp12 - ((iTemp13) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp13, 1)) as usize] } - fTemp14));
			self.fVec2[0] = fTemp79;
			self.fRec0[0] = 0.115 * (self.fConst16 * fTemp79 + self.fConst17 * self.fVec2[1]) - self.fConst4 * self.fRec0[1];
			*output0 = fSlow18 * self.fRec0[0];
			*output1 = fSlow19 * self.fRec0[0];
			*output2 = fSlow20 * self.fRec0[0];
			self.fVec0[1] = self.fVec0[0];
			self.fRec5[1] = self.fRec5[0];
			self.fRec4[1] = self.fRec4[0];
			self.fRec6[1] = self.fRec6[0];
			self.fRec8[1] = self.fRec8[0];
			self.fRec9[1] = self.fRec9[0];
			self.fRec3[1] = self.fRec3[0];
			self.fRec2[1] = self.fRec2[0];
			self.fRec13[1] = self.fRec13[0];
			self.fRec14[1] = self.fRec14[0];
			self.fRec15[1] = self.fRec15[0];
			self.fRec16[1] = self.fRec16[0];
			self.fRec12[1] = self.fRec12[0];
			self.fRec11[1] = self.fRec11[0];
			self.iRec21[1] = self.iRec21[0];
			self.iRec22[1] = self.iRec22[0];
			self.fRec23[1] = self.fRec23[0];
			self.fRec20[1] = self.fRec20[0];
			self.fRec19[1] = self.fRec19[0];
			self.fRec17[1] = self.fRec17[0];
			self.fRec26[1] = self.fRec26[0];
			self.fRec27[1] = self.fRec27[0];
			self.fRec28[1] = self.fRec28[0];
			self.fRec25[1] = self.fRec25[0];
			self.fRec24[1] = self.fRec24[0];
			self.fRec29[1] = self.fRec29[0];
			self.fRec33[1] = self.fRec33[0];
			self.fRec34[1] = self.fRec34[0];
			self.fRec35[1] = self.fRec35[0];
			self.fRec32[1] = self.fRec32[0];
			self.fRec31[1] = self.fRec31[0];
			self.fRec36[1] = self.fRec36[0];
			self.fVec2[1] = self.fVec2[0];
			self.fRec0[1] = self.fRec0[0];
		}
	}
}
impl DSP_Cowbell3 {
    /*
       This function was copied from above and
       tweaked to enable auto-vectorization using sse4.1
    */
    #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
    #[target_feature(enable = "sse4.1")]
	unsafe fn compute_x86_or_x86_64_using_sse4_1(&mut self, count: i32, inputs: &[&[<DSP_Cowbell3 as FaustDsp>::T]], outputs: &mut[&mut[<DSP_Cowbell3 as FaustDsp>::T]]) {
		let (outputs0, outputs1, outputs2) = if let [outputs0, outputs1, outputs2, ..] = outputs {
			let outputs0 = outputs0[..count as usize].iter_mut();
			let outputs1 = outputs1[..count as usize].iter_mut();
			let outputs2 = outputs2[..count as usize].iter_mut();
			(outputs0, outputs1, outputs2)
		} else {
			panic!("wrong number of outputs");
		};
		let mut fSlow0: F32 = self.fButton0;
		let mut iSlow1: i32 = ((fSlow0 > 0.0) as i32);
		let mut iSlow2: i32 = ((iSlow1 > 0) as i32);
		let mut fSlow3: F32 = self.fHslider0;
		let mut fSlow4: F32 = self.fEntry0;
		let mut iSlow5: i32 = ((fSlow4 > 0.0) as i32);
		let mut iSlow6: i32 = (((((fSlow0 == 0.0) as i32)) > 0) as i32);
		let mut fSlow7: F32 = ((iSlow1) as F32);
		let mut fSlow8: F32 = F32::powf(2.0, 0.083333336 * (self.fHslider2 + self.fHslider1 + -79.0));
		let mut fSlow9: F32 = 15.996094 * (0.1 * (1.0 - 0.008333334 * (17.31234 * F32::log(fSlow8, std::f32::consts::E) + 48.0)) + 128.0);
		let mut iSlow10: i32 = ((fSlow9) as i32);
		let mut fSlow11: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iSlow10) as usize] };
		let mut fSlow12: F32 = fSlow11 + (fSlow9 - ((iSlow10) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iSlow10, 1)) as usize] } - fSlow11);
		let mut fSlow13: F32 = self.fConst13 * fSlow8;
		let mut fSlow14: F32 = self.fConst14 * fSlow8;
		let mut fSlow15: F32 = self.fConst15 * fSlow8;
		let mut fSlow16: F32 = 0.01 * self.fHslider3;
		let mut fSlow17: F32 = F32::powf(1e+01, 0.05 * F32::max(-1e+02, self.fHslider4 + -2.0));
		let mut fSlow18: F32 = fSlow17 * F32::min(1.0, 1.0 - fSlow16);
		let mut fSlow19: F32 = fSlow17 * F32::min(1.0, fSlow16 + 1.0);
		let mut fSlow20: F32 = 0.01 * self.fHslider5 * fSlow17;
		let zipped_iterators = outputs0.zip(outputs1).zip(outputs2);
		for ((output0, output1), output2) in zipped_iterators {
			self.fVec0[0] = fSlow0;
			let mut iTemp1: i32 = i32::wrapping_sub(1, ((fSlow0 > self.fVec0[1]) as i32));
			self.fRec5[0] = if (iSlow5 as i32 != 0) { fSlow4 } else { self.fRec5[1] };
			let mut fTemp2: F32 = F32::max(0.0, F32::min(127.0, 0.14285715 * (106.0 * (1.0 - DSP_Cowbell3_faustpower2_f(1.0 - F32::max(fSlow3, self.fRec5[0]))) + -99.0) + 85.0));
			let mut fTemp3: F32 = 32.0 * F32::min(1.0, 0.05 * fTemp2) * (fTemp2 + 28.0);
			self.fRec4[0] = if (iTemp1 as i32 != 0) { fTemp3 } else { self.fRec4[1] };
			let mut fTemp4: F32 = F32::max(5076.0, self.fRec4[0]);
			self.fRec6[0] = if (iTemp1 as i32 != 0) { fTemp3 + 4064.0 } else { self.fRec6[1] };
			let mut fTemp5: F32 = self.fRec6[0] - fTemp4;
			self.fRec8[0] = if (iTemp1 as i32 != 0) { 0.0 } else { self.fRec8[1] };
			let mut fTemp6: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp5) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 88.0) as i32)) as usize] } * if (((fTemp5 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp4)) + 2.0) } else { 0.96 }))));
			self.fRec9[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp6, self.fRec9[1] + 1.0) };
			let mut iTemp7: i32 = ((self.fRec9[0] < fTemp6) as i32);
			let mut fTemp8: F32 = self.fRec9[0] / fTemp6;
			self.fRec3[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec9[0] < (self.fConst5 + fTemp6)) as i32) as i32 != 0) { if (iTemp7 as i32 != 0) { if (((self.fRec9[0] < 0.0) as i32) as i32 != 0) { fTemp4 } else { if (iTemp7 as i32 != 0) { fTemp4 + fTemp5 * if (((self.fRec6[0] > fTemp4) as i32) as i32 != 0) { F32::powf(fTemp8, 0.33333334) } else { fTemp8 } } else { self.fRec6[0] } } } else { self.fRec6[0] } } else { self.fRec6[0] } } else { self.fRec3[1] };
			let mut fTemp9: F32 = self.fRec4[0] - self.fRec3[0];
			let mut fTemp10: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp9) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 7e+01) as i32)) as usize] } * if (((fTemp9 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec3[0])) + 2.0) } else { 0.96 }))));
			self.fRec2[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp10, self.fRec2[1] + 1.0) };
			let mut fTemp11: F32 = self.fRec2[0] / fTemp10;
			let mut fTemp12: F32 = if (((self.fRec2[0] < 0.0) as i32) as i32 != 0) { self.fRec3[0] } else { if (((self.fRec2[0] < fTemp10) as i32) as i32 != 0) { self.fRec3[0] + fTemp9 * if (((self.fRec4[0] > self.fRec3[0]) as i32) as i32 != 0) { F32::powf(fTemp11, 0.33333334) } else { fTemp11 } } else { self.fRec4[0] } };
			let mut iTemp13: i32 = ((fTemp12) as i32);
			let mut fTemp14: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp13) as usize] };
			self.fRec13[0] = if (iTemp1 as i32 != 0) { 6944.0 } else { self.fRec13[1] };
			self.fRec14[0] = if (iTemp1 as i32 != 0) { 6.72e+03 } else { self.fRec14[1] };
			let mut fTemp15: F32 = self.fRec14[0] - self.fRec13[0];
			let mut fTemp16: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp15) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 68.0) as i32)) as usize] } * if (((fTemp15 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec13[0])) + 2.0) } else { 0.96 }))));
			self.fRec15[0] = if (iTemp1 as i32 != 0) { 2976.0 } else { self.fRec15[1] };
			let mut fTemp17: F32 = F32::max(5076.0, self.fRec15[0]);
			let mut fTemp18: F32 = self.fRec13[0] - fTemp17;
			let mut fTemp19: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp18) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 94.0) as i32)) as usize] } * if (((fTemp18 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp17)) + 2.0) } else { 0.96 }))));
			let mut fTemp20: F32 = fTemp19 + fTemp16;
			let mut fTemp21: F32 = self.fRec15[0] - self.fRec14[0];
			let mut fTemp22: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp21) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 24.0) as i32)) as usize] } * if (((fTemp21 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec14[0])) + 2.0) } else { 0.96 }))));
			let mut fTemp23: F32 = fTemp20 + fTemp22;
			self.fRec16[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp23, self.fRec16[1] + 1.0) };
			let mut iTemp24: i32 = ((self.fRec16[0] < fTemp20) as i32);
			let mut fTemp25: F32 = (self.fRec16[0] - fTemp20) / fTemp22;
			let mut iTemp26: i32 = ((self.fRec16[0] < fTemp19) as i32);
			let mut fTemp27: F32 = (self.fRec16[0] - fTemp19) / fTemp16;
			let mut fTemp28: F32 = self.fRec16[0] / fTemp19;
			self.fRec12[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp24 as i32 != 0) { if (iTemp26 as i32 != 0) { if (((self.fRec16[0] < 0.0) as i32) as i32 != 0) { fTemp17 } else { if (iTemp26 as i32 != 0) { fTemp17 + fTemp18 * if (((self.fRec13[0] > fTemp17) as i32) as i32 != 0) { F32::powf(fTemp28, 0.33333334) } else { fTemp28 } } else { self.fRec13[0] } } } else { if (iTemp24 as i32 != 0) { self.fRec13[0] + fTemp15 * if (((self.fRec14[0] > self.fRec13[0]) as i32) as i32 != 0) { F32::powf(fTemp27, 0.33333334) } else { fTemp27 } } else { self.fRec14[0] } } } else { if (((self.fRec16[0] < fTemp23) as i32) as i32 != 0) { self.fRec14[0] + fTemp21 * if (((self.fRec15[0] > self.fRec14[0]) as i32) as i32 != 0) { F32::powf(fTemp25, 0.33333334) } else { fTemp25 } } else { self.fRec15[0] } } } else { self.fRec12[1] };
			let mut fTemp29: F32 = self.fRec15[0] - self.fRec12[0];
			let mut fTemp30: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp29) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 55.0) as i32)) as usize] } * if (((fTemp29 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec12[0])) + 2.0) } else { 0.96 }))));
			self.fRec11[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp30, self.fRec11[1] + 1.0) };
			let mut fTemp31: F32 = self.fRec11[0] / fTemp30;
			let mut fTemp32: F32 = if (((self.fRec11[0] < 0.0) as i32) as i32 != 0) { self.fRec12[0] } else { if (((self.fRec11[0] < fTemp30) as i32) as i32 != 0) { self.fRec12[0] + fTemp29 * if (((self.fRec15[0] > self.fRec12[0]) as i32) as i32 != 0) { F32::powf(fTemp31, 0.33333334) } else { fTemp31 } } else { self.fRec15[0] } };
			let mut iTemp33: i32 = ((fTemp32) as i32);
			let mut fTemp34: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp33) as usize] };
			self.iRec21[0] = if (iTemp1 as i32 != 0) { self.iConst9 } else { self.iRec21[1] };
			self.iRec22[0] = if (iTemp1 as i32 != 0) { self.iConst10 } else { self.iRec22[1] };
			let mut iTemp35: i32 = i32::wrapping_sub(self.iRec22[0], self.iRec21[0]);
			let mut fTemp36: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp35)) as F32) / self.fConst8));
			let mut iTemp37: i32 = i32::wrapping_sub(self.iRec21[0], self.iRec22[0]);
			let mut fTemp38: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp37)) as F32) / self.fConst12));
			let mut fTemp39: F32 = fTemp38 + fTemp36;
			self.fRec23[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp39 + 1.0, self.fRec23[1] + 1.0) };
			let mut iTemp40: i32 = ((self.fRec23[0] < fTemp39) as i32);
			let mut fTemp41: F32 = ((self.iRec22[0]) as F32);
			let mut iTemp42: i32 = ((self.fRec23[0] < fTemp38) as i32);
			let mut fTemp43: F32 = (self.fRec23[0] - fTemp38) / fTemp36;
			let mut fTemp44: F32 = ((self.iRec21[0]) as F32);
			let mut fTemp45: F32 = self.fRec23[0] / fTemp38;
			self.fRec20[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp40 as i32 != 0) { if (iTemp42 as i32 != 0) { if (((self.fRec23[0] < 0.0) as i32) as i32 != 0) { fTemp41 } else { if (iTemp42 as i32 != 0) { fTemp41 + ((iTemp37) as F32) * if (((self.iRec21[0] > self.iRec22[0]) as i32) as i32 != 0) { F32::powf(fTemp45, 0.33333334) } else { fTemp45 } } else { fTemp44 } } } else { if (iTemp40 as i32 != 0) { fTemp44 + ((iTemp35) as F32) * if (((self.iRec22[0] > self.iRec21[0]) as i32) as i32 != 0) { F32::powf(fTemp43, 0.33333334) } else { fTemp43 } } else { fTemp41 } } } else { fTemp41 } } else { self.fRec20[1] };
			let mut fTemp46: F32 = fTemp41 - self.fRec20[0];
			let mut fTemp47: F32 = F32::max(1.0, self.fConst11 * (F32::abs(fTemp46) / self.fConst7));
			self.fRec19[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp47, self.fRec19[1] + 1.0) };
			let mut fTemp48: F32 = self.fRec19[0] / fTemp47;
			let mut fTemp49: F32 = 15.996094 * (0.4 * if (((self.fRec19[0] < 0.0) as i32) as i32 != 0) { self.fRec20[0] } else { if (((self.fRec19[0] < fTemp47) as i32) as i32 != 0) { self.fRec20[0] + fTemp46 * if (((fTemp41 > self.fRec20[0]) as i32) as i32 != 0) { F32::powf(fTemp48, 0.33333334) } else { fTemp48 } } else { fTemp41 } } + 128.0);
			let mut iTemp50: i32 = ((fTemp49) as i32);
			let mut fTemp51: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iTemp50) as usize] };
			let mut fTemp52: F32 = fSlow12 * (fTemp51 + (fTemp49 - ((iTemp50) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iTemp50, 1)) as usize] } - fTemp51));
			let mut fTemp53: F32 = self.fRec17[1] + fSlow13 * fTemp52;
			self.fRec17[0] = fTemp53 - F32::floor(fTemp53);
			self.fRec26[0] = if (iTemp1 as i32 != 0) { 3872.0 } else { self.fRec26[1] };
			let mut fTemp54: F32 = F32::max(5076.0, self.fRec26[0]);
			self.fRec27[0] = if (iTemp1 as i32 != 0) { 7936.0 } else { self.fRec27[1] };
			let mut fTemp55: F32 = self.fRec27[0] - fTemp54;
			let mut fTemp56: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp55) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 71.0) as i32)) as usize] } * if (((fTemp55 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp54)) + 2.0) } else { 0.96 }))));
			self.fRec28[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp56, self.fRec28[1] + 1.0) };
			let mut iTemp57: i32 = ((self.fRec28[0] < fTemp56) as i32);
			let mut fTemp58: F32 = self.fRec28[0] / fTemp56;
			self.fRec25[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec28[0] < (self.fConst5 + fTemp56)) as i32) as i32 != 0) { if (iTemp57 as i32 != 0) { if (((self.fRec28[0] < 0.0) as i32) as i32 != 0) { fTemp54 } else { if (iTemp57 as i32 != 0) { fTemp54 + fTemp55 * if (((self.fRec27[0] > fTemp54) as i32) as i32 != 0) { F32::powf(fTemp58, 0.33333334) } else { fTemp58 } } else { self.fRec27[0] } } } else { self.fRec27[0] } } else { self.fRec27[0] } } else { self.fRec25[1] };
			let mut fTemp59: F32 = self.fRec26[0] - self.fRec25[0];
			let mut fTemp60: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp59) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 51.0) as i32)) as usize] } * if (((fTemp59 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec25[0])) + 2.0) } else { 0.96 }))));
			self.fRec24[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp60, self.fRec24[1] + 1.0) };
			let mut fTemp61: F32 = self.fRec24[0] / fTemp60;
			let mut fTemp62: F32 = if (((self.fRec24[0] < 0.0) as i32) as i32 != 0) { self.fRec25[0] } else { if (((self.fRec24[0] < fTemp60) as i32) as i32 != 0) { self.fRec25[0] + fTemp59 * if (((self.fRec26[0] > self.fRec25[0]) as i32) as i32 != 0) { F32::powf(fTemp61, 0.33333334) } else { fTemp61 } } else { self.fRec26[0] } };
			let mut iTemp63: i32 = ((fTemp62) as i32);
			let mut fTemp64: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp63) as usize] };
			let mut fTemp65: F32 = self.fRec29[1] + fSlow14 * fTemp52;
			self.fRec29[0] = fTemp65 - F32::floor(fTemp65);
			let mut fTemp66: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec29[0] + 1.024e+04) as i32) % 1024) as usize] };
			self.fRec33[0] = if (iTemp1 as i32 != 0) { 3.04e+03 } else { self.fRec33[1] };
			let mut fTemp67: F32 = F32::max(5076.0, self.fRec33[0]);
			self.fRec34[0] = if (iTemp1 as i32 != 0) { 7104.0 } else { self.fRec34[1] };
			let mut fTemp68: F32 = self.fRec34[0] - fTemp67;
			let mut fTemp69: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp68) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 67.0) as i32)) as usize] } * if (((fTemp68 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp67)) + 2.0) } else { 0.96 }))));
			self.fRec35[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp69, self.fRec35[1] + 1.0) };
			let mut iTemp70: i32 = ((self.fRec35[0] < fTemp69) as i32);
			let mut fTemp71: F32 = self.fRec35[0] / fTemp69;
			self.fRec32[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec35[0] < (self.fConst5 + fTemp69)) as i32) as i32 != 0) { if (iTemp70 as i32 != 0) { if (((self.fRec35[0] < 0.0) as i32) as i32 != 0) { fTemp67 } else { if (iTemp70 as i32 != 0) { fTemp67 + fTemp68 * if (((self.fRec34[0] > fTemp67) as i32) as i32 != 0) { F32::powf(fTemp71, 0.33333334) } else { fTemp71 } } else { self.fRec34[0] } } } else { self.fRec34[0] } } else { self.fRec34[0] } } else { self.fRec32[1] };
			let mut fTemp72: F32 = self.fRec33[0] - self.fRec32[0];
			let mut fTemp73: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp72) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 4e+01) as i32)) as usize] } * if (((fTemp72 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec32[0])) + 2.0) } else { 0.96 }))));
			self.fRec31[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp73, self.fRec31[1] + 1.0) };
			let mut fTemp74: F32 = self.fRec31[0] / fTemp73;
			let mut fTemp75: F32 = if (((self.fRec31[0] < 0.0) as i32) as i32 != 0) { self.fRec32[0] } else { if (((self.fRec31[0] < fTemp73) as i32) as i32 != 0) { self.fRec32[0] + fTemp72 * if (((self.fRec33[0] > self.fRec32[0]) as i32) as i32 != 0) { F32::powf(fTemp74, 0.33333334) } else { fTemp74 } } else { self.fRec33[0] } };
			let mut iTemp76: i32 = ((fTemp75) as i32);
			let mut fTemp77: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp76) as usize] };
			let mut fRec30: F32 = 0.115 * fTemp66 * (fTemp77 + (fTemp75 - ((iTemp76) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp76, 1)) as usize] } - fTemp77));
			let mut fTemp78: F32 = self.fRec36[1] + fSlow15 * fTemp52;
			self.fRec36[0] = fTemp78 - F32::floor(fTemp78);
			let mut fTemp79: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * (self.fRec36[0] + 17.391304 * (fRec30 + 0.115 * (fTemp66 * (fTemp64 + (fTemp62 - ((iTemp63) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp63, 1)) as usize] } - fTemp64)) + unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec17[0] + 1.024e+04) as i32) % 1024) as usize] } * (fTemp34 + (fTemp32 - ((iTemp33) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp33, 1)) as usize] } - fTemp34)))) + 1e+01)) as i32) % 1024) as usize] } * (fTemp14 + (fTemp12 - ((iTemp13) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp13, 1)) as usize] } - fTemp14));
			self.fVec2[0] = fTemp79;
			self.fRec0[0] = 0.115 * (self.fConst16 * fTemp79 + self.fConst17 * self.fVec2[1]) - self.fConst4 * self.fRec0[1];
			*output0 = fSlow18 * self.fRec0[0];
			*output1 = fSlow19 * self.fRec0[0];
			*output2 = fSlow20 * self.fRec0[0];
			self.fVec0[1] = self.fVec0[0];
			self.fRec5[1] = self.fRec5[0];
			self.fRec4[1] = self.fRec4[0];
			self.fRec6[1] = self.fRec6[0];
			self.fRec8[1] = self.fRec8[0];
			self.fRec9[1] = self.fRec9[0];
			self.fRec3[1] = self.fRec3[0];
			self.fRec2[1] = self.fRec2[0];
			self.fRec13[1] = self.fRec13[0];
			self.fRec14[1] = self.fRec14[0];
			self.fRec15[1] = self.fRec15[0];
			self.fRec16[1] = self.fRec16[0];
			self.fRec12[1] = self.fRec12[0];
			self.fRec11[1] = self.fRec11[0];
			self.iRec21[1] = self.iRec21[0];
			self.iRec22[1] = self.iRec22[0];
			self.fRec23[1] = self.fRec23[0];
			self.fRec20[1] = self.fRec20[0];
			self.fRec19[1] = self.fRec19[0];
			self.fRec17[1] = self.fRec17[0];
			self.fRec26[1] = self.fRec26[0];
			self.fRec27[1] = self.fRec27[0];
			self.fRec28[1] = self.fRec28[0];
			self.fRec25[1] = self.fRec25[0];
			self.fRec24[1] = self.fRec24[0];
			self.fRec29[1] = self.fRec29[0];
			self.fRec33[1] = self.fRec33[0];
			self.fRec34[1] = self.fRec34[0];
			self.fRec35[1] = self.fRec35[0];
			self.fRec32[1] = self.fRec32[0];
			self.fRec31[1] = self.fRec31[0];
			self.fRec36[1] = self.fRec36[0];
			self.fVec2[1] = self.fVec2[0];
			self.fRec0[1] = self.fRec0[0];
		}
	}
}
impl DSP_Cowbell3 {
    /*
       This function was copied from above and
       tweaked to enable auto-vectorization using avx
    */
    #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
    #[target_feature(enable = "avx")]
	unsafe fn compute_x86_or_x86_64_using_avx(&mut self, count: i32, inputs: &[&[<DSP_Cowbell3 as FaustDsp>::T]], outputs: &mut[&mut[<DSP_Cowbell3 as FaustDsp>::T]]) {
		let (outputs0, outputs1, outputs2) = if let [outputs0, outputs1, outputs2, ..] = outputs {
			let outputs0 = outputs0[..count as usize].iter_mut();
			let outputs1 = outputs1[..count as usize].iter_mut();
			let outputs2 = outputs2[..count as usize].iter_mut();
			(outputs0, outputs1, outputs2)
		} else {
			panic!("wrong number of outputs");
		};
		let mut fSlow0: F32 = self.fButton0;
		let mut iSlow1: i32 = ((fSlow0 > 0.0) as i32);
		let mut iSlow2: i32 = ((iSlow1 > 0) as i32);
		let mut fSlow3: F32 = self.fHslider0;
		let mut fSlow4: F32 = self.fEntry0;
		let mut iSlow5: i32 = ((fSlow4 > 0.0) as i32);
		let mut iSlow6: i32 = (((((fSlow0 == 0.0) as i32)) > 0) as i32);
		let mut fSlow7: F32 = ((iSlow1) as F32);
		let mut fSlow8: F32 = F32::powf(2.0, 0.083333336 * (self.fHslider2 + self.fHslider1 + -79.0));
		let mut fSlow9: F32 = 15.996094 * (0.1 * (1.0 - 0.008333334 * (17.31234 * F32::log(fSlow8, std::f32::consts::E) + 48.0)) + 128.0);
		let mut iSlow10: i32 = ((fSlow9) as i32);
		let mut fSlow11: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iSlow10) as usize] };
		let mut fSlow12: F32 = fSlow11 + (fSlow9 - ((iSlow10) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iSlow10, 1)) as usize] } - fSlow11);
		let mut fSlow13: F32 = self.fConst13 * fSlow8;
		let mut fSlow14: F32 = self.fConst14 * fSlow8;
		let mut fSlow15: F32 = self.fConst15 * fSlow8;
		let mut fSlow16: F32 = 0.01 * self.fHslider3;
		let mut fSlow17: F32 = F32::powf(1e+01, 0.05 * F32::max(-1e+02, self.fHslider4 + -2.0));
		let mut fSlow18: F32 = fSlow17 * F32::min(1.0, 1.0 - fSlow16);
		let mut fSlow19: F32 = fSlow17 * F32::min(1.0, fSlow16 + 1.0);
		let mut fSlow20: F32 = 0.01 * self.fHslider5 * fSlow17;
		let zipped_iterators = outputs0.zip(outputs1).zip(outputs2);
		for ((output0, output1), output2) in zipped_iterators {
			self.fVec0[0] = fSlow0;
			let mut iTemp1: i32 = i32::wrapping_sub(1, ((fSlow0 > self.fVec0[1]) as i32));
			self.fRec5[0] = if (iSlow5 as i32 != 0) { fSlow4 } else { self.fRec5[1] };
			let mut fTemp2: F32 = F32::max(0.0, F32::min(127.0, 0.14285715 * (106.0 * (1.0 - DSP_Cowbell3_faustpower2_f(1.0 - F32::max(fSlow3, self.fRec5[0]))) + -99.0) + 85.0));
			let mut fTemp3: F32 = 32.0 * F32::min(1.0, 0.05 * fTemp2) * (fTemp2 + 28.0);
			self.fRec4[0] = if (iTemp1 as i32 != 0) { fTemp3 } else { self.fRec4[1] };
			let mut fTemp4: F32 = F32::max(5076.0, self.fRec4[0]);
			self.fRec6[0] = if (iTemp1 as i32 != 0) { fTemp3 + 4064.0 } else { self.fRec6[1] };
			let mut fTemp5: F32 = self.fRec6[0] - fTemp4;
			self.fRec8[0] = if (iTemp1 as i32 != 0) { 0.0 } else { self.fRec8[1] };
			let mut fTemp6: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp5) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 88.0) as i32)) as usize] } * if (((fTemp5 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp4)) + 2.0) } else { 0.96 }))));
			self.fRec9[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp6, self.fRec9[1] + 1.0) };
			let mut iTemp7: i32 = ((self.fRec9[0] < fTemp6) as i32);
			let mut fTemp8: F32 = self.fRec9[0] / fTemp6;
			self.fRec3[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec9[0] < (self.fConst5 + fTemp6)) as i32) as i32 != 0) { if (iTemp7 as i32 != 0) { if (((self.fRec9[0] < 0.0) as i32) as i32 != 0) { fTemp4 } else { if (iTemp7 as i32 != 0) { fTemp4 + fTemp5 * if (((self.fRec6[0] > fTemp4) as i32) as i32 != 0) { F32::powf(fTemp8, 0.33333334) } else { fTemp8 } } else { self.fRec6[0] } } } else { self.fRec6[0] } } else { self.fRec6[0] } } else { self.fRec3[1] };
			let mut fTemp9: F32 = self.fRec4[0] - self.fRec3[0];
			let mut fTemp10: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp9) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 7e+01) as i32)) as usize] } * if (((fTemp9 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec3[0])) + 2.0) } else { 0.96 }))));
			self.fRec2[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp10, self.fRec2[1] + 1.0) };
			let mut fTemp11: F32 = self.fRec2[0] / fTemp10;
			let mut fTemp12: F32 = if (((self.fRec2[0] < 0.0) as i32) as i32 != 0) { self.fRec3[0] } else { if (((self.fRec2[0] < fTemp10) as i32) as i32 != 0) { self.fRec3[0] + fTemp9 * if (((self.fRec4[0] > self.fRec3[0]) as i32) as i32 != 0) { F32::powf(fTemp11, 0.33333334) } else { fTemp11 } } else { self.fRec4[0] } };
			let mut iTemp13: i32 = ((fTemp12) as i32);
			let mut fTemp14: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp13) as usize] };
			self.fRec13[0] = if (iTemp1 as i32 != 0) { 6944.0 } else { self.fRec13[1] };
			self.fRec14[0] = if (iTemp1 as i32 != 0) { 6.72e+03 } else { self.fRec14[1] };
			let mut fTemp15: F32 = self.fRec14[0] - self.fRec13[0];
			let mut fTemp16: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp15) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 68.0) as i32)) as usize] } * if (((fTemp15 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec13[0])) + 2.0) } else { 0.96 }))));
			self.fRec15[0] = if (iTemp1 as i32 != 0) { 2976.0 } else { self.fRec15[1] };
			let mut fTemp17: F32 = F32::max(5076.0, self.fRec15[0]);
			let mut fTemp18: F32 = self.fRec13[0] - fTemp17;
			let mut fTemp19: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp18) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 94.0) as i32)) as usize] } * if (((fTemp18 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp17)) + 2.0) } else { 0.96 }))));
			let mut fTemp20: F32 = fTemp19 + fTemp16;
			let mut fTemp21: F32 = self.fRec15[0] - self.fRec14[0];
			let mut fTemp22: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp21) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 24.0) as i32)) as usize] } * if (((fTemp21 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec14[0])) + 2.0) } else { 0.96 }))));
			let mut fTemp23: F32 = fTemp20 + fTemp22;
			self.fRec16[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp23, self.fRec16[1] + 1.0) };
			let mut iTemp24: i32 = ((self.fRec16[0] < fTemp20) as i32);
			let mut fTemp25: F32 = (self.fRec16[0] - fTemp20) / fTemp22;
			let mut iTemp26: i32 = ((self.fRec16[0] < fTemp19) as i32);
			let mut fTemp27: F32 = (self.fRec16[0] - fTemp19) / fTemp16;
			let mut fTemp28: F32 = self.fRec16[0] / fTemp19;
			self.fRec12[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp24 as i32 != 0) { if (iTemp26 as i32 != 0) { if (((self.fRec16[0] < 0.0) as i32) as i32 != 0) { fTemp17 } else { if (iTemp26 as i32 != 0) { fTemp17 + fTemp18 * if (((self.fRec13[0] > fTemp17) as i32) as i32 != 0) { F32::powf(fTemp28, 0.33333334) } else { fTemp28 } } else { self.fRec13[0] } } } else { if (iTemp24 as i32 != 0) { self.fRec13[0] + fTemp15 * if (((self.fRec14[0] > self.fRec13[0]) as i32) as i32 != 0) { F32::powf(fTemp27, 0.33333334) } else { fTemp27 } } else { self.fRec14[0] } } } else { if (((self.fRec16[0] < fTemp23) as i32) as i32 != 0) { self.fRec14[0] + fTemp21 * if (((self.fRec15[0] > self.fRec14[0]) as i32) as i32 != 0) { F32::powf(fTemp25, 0.33333334) } else { fTemp25 } } else { self.fRec15[0] } } } else { self.fRec12[1] };
			let mut fTemp29: F32 = self.fRec15[0] - self.fRec12[0];
			let mut fTemp30: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp29) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 55.0) as i32)) as usize] } * if (((fTemp29 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec12[0])) + 2.0) } else { 0.96 }))));
			self.fRec11[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp30, self.fRec11[1] + 1.0) };
			let mut fTemp31: F32 = self.fRec11[0] / fTemp30;
			let mut fTemp32: F32 = if (((self.fRec11[0] < 0.0) as i32) as i32 != 0) { self.fRec12[0] } else { if (((self.fRec11[0] < fTemp30) as i32) as i32 != 0) { self.fRec12[0] + fTemp29 * if (((self.fRec15[0] > self.fRec12[0]) as i32) as i32 != 0) { F32::powf(fTemp31, 0.33333334) } else { fTemp31 } } else { self.fRec15[0] } };
			let mut iTemp33: i32 = ((fTemp32) as i32);
			let mut fTemp34: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp33) as usize] };
			self.iRec21[0] = if (iTemp1 as i32 != 0) { self.iConst9 } else { self.iRec21[1] };
			self.iRec22[0] = if (iTemp1 as i32 != 0) { self.iConst10 } else { self.iRec22[1] };
			let mut iTemp35: i32 = i32::wrapping_sub(self.iRec22[0], self.iRec21[0]);
			let mut fTemp36: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp35)) as F32) / self.fConst8));
			let mut iTemp37: i32 = i32::wrapping_sub(self.iRec21[0], self.iRec22[0]);
			let mut fTemp38: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp37)) as F32) / self.fConst12));
			let mut fTemp39: F32 = fTemp38 + fTemp36;
			self.fRec23[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp39 + 1.0, self.fRec23[1] + 1.0) };
			let mut iTemp40: i32 = ((self.fRec23[0] < fTemp39) as i32);
			let mut fTemp41: F32 = ((self.iRec22[0]) as F32);
			let mut iTemp42: i32 = ((self.fRec23[0] < fTemp38) as i32);
			let mut fTemp43: F32 = (self.fRec23[0] - fTemp38) / fTemp36;
			let mut fTemp44: F32 = ((self.iRec21[0]) as F32);
			let mut fTemp45: F32 = self.fRec23[0] / fTemp38;
			self.fRec20[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp40 as i32 != 0) { if (iTemp42 as i32 != 0) { if (((self.fRec23[0] < 0.0) as i32) as i32 != 0) { fTemp41 } else { if (iTemp42 as i32 != 0) { fTemp41 + ((iTemp37) as F32) * if (((self.iRec21[0] > self.iRec22[0]) as i32) as i32 != 0) { F32::powf(fTemp45, 0.33333334) } else { fTemp45 } } else { fTemp44 } } } else { if (iTemp40 as i32 != 0) { fTemp44 + ((iTemp35) as F32) * if (((self.iRec22[0] > self.iRec21[0]) as i32) as i32 != 0) { F32::powf(fTemp43, 0.33333334) } else { fTemp43 } } else { fTemp41 } } } else { fTemp41 } } else { self.fRec20[1] };
			let mut fTemp46: F32 = fTemp41 - self.fRec20[0];
			let mut fTemp47: F32 = F32::max(1.0, self.fConst11 * (F32::abs(fTemp46) / self.fConst7));
			self.fRec19[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp47, self.fRec19[1] + 1.0) };
			let mut fTemp48: F32 = self.fRec19[0] / fTemp47;
			let mut fTemp49: F32 = 15.996094 * (0.4 * if (((self.fRec19[0] < 0.0) as i32) as i32 != 0) { self.fRec20[0] } else { if (((self.fRec19[0] < fTemp47) as i32) as i32 != 0) { self.fRec20[0] + fTemp46 * if (((fTemp41 > self.fRec20[0]) as i32) as i32 != 0) { F32::powf(fTemp48, 0.33333334) } else { fTemp48 } } else { fTemp41 } } + 128.0);
			let mut iTemp50: i32 = ((fTemp49) as i32);
			let mut fTemp51: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iTemp50) as usize] };
			let mut fTemp52: F32 = fSlow12 * (fTemp51 + (fTemp49 - ((iTemp50) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iTemp50, 1)) as usize] } - fTemp51));
			let mut fTemp53: F32 = self.fRec17[1] + fSlow13 * fTemp52;
			self.fRec17[0] = fTemp53 - F32::floor(fTemp53);
			self.fRec26[0] = if (iTemp1 as i32 != 0) { 3872.0 } else { self.fRec26[1] };
			let mut fTemp54: F32 = F32::max(5076.0, self.fRec26[0]);
			self.fRec27[0] = if (iTemp1 as i32 != 0) { 7936.0 } else { self.fRec27[1] };
			let mut fTemp55: F32 = self.fRec27[0] - fTemp54;
			let mut fTemp56: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp55) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 71.0) as i32)) as usize] } * if (((fTemp55 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp54)) + 2.0) } else { 0.96 }))));
			self.fRec28[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp56, self.fRec28[1] + 1.0) };
			let mut iTemp57: i32 = ((self.fRec28[0] < fTemp56) as i32);
			let mut fTemp58: F32 = self.fRec28[0] / fTemp56;
			self.fRec25[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec28[0] < (self.fConst5 + fTemp56)) as i32) as i32 != 0) { if (iTemp57 as i32 != 0) { if (((self.fRec28[0] < 0.0) as i32) as i32 != 0) { fTemp54 } else { if (iTemp57 as i32 != 0) { fTemp54 + fTemp55 * if (((self.fRec27[0] > fTemp54) as i32) as i32 != 0) { F32::powf(fTemp58, 0.33333334) } else { fTemp58 } } else { self.fRec27[0] } } } else { self.fRec27[0] } } else { self.fRec27[0] } } else { self.fRec25[1] };
			let mut fTemp59: F32 = self.fRec26[0] - self.fRec25[0];
			let mut fTemp60: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp59) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 51.0) as i32)) as usize] } * if (((fTemp59 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec25[0])) + 2.0) } else { 0.96 }))));
			self.fRec24[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp60, self.fRec24[1] + 1.0) };
			let mut fTemp61: F32 = self.fRec24[0] / fTemp60;
			let mut fTemp62: F32 = if (((self.fRec24[0] < 0.0) as i32) as i32 != 0) { self.fRec25[0] } else { if (((self.fRec24[0] < fTemp60) as i32) as i32 != 0) { self.fRec25[0] + fTemp59 * if (((self.fRec26[0] > self.fRec25[0]) as i32) as i32 != 0) { F32::powf(fTemp61, 0.33333334) } else { fTemp61 } } else { self.fRec26[0] } };
			let mut iTemp63: i32 = ((fTemp62) as i32);
			let mut fTemp64: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp63) as usize] };
			let mut fTemp65: F32 = self.fRec29[1] + fSlow14 * fTemp52;
			self.fRec29[0] = fTemp65 - F32::floor(fTemp65);
			let mut fTemp66: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec29[0] + 1.024e+04) as i32) % 1024) as usize] };
			self.fRec33[0] = if (iTemp1 as i32 != 0) { 3.04e+03 } else { self.fRec33[1] };
			let mut fTemp67: F32 = F32::max(5076.0, self.fRec33[0]);
			self.fRec34[0] = if (iTemp1 as i32 != 0) { 7104.0 } else { self.fRec34[1] };
			let mut fTemp68: F32 = self.fRec34[0] - fTemp67;
			let mut fTemp69: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp68) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 67.0) as i32)) as usize] } * if (((fTemp68 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp67)) + 2.0) } else { 0.96 }))));
			self.fRec35[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp69, self.fRec35[1] + 1.0) };
			let mut iTemp70: i32 = ((self.fRec35[0] < fTemp69) as i32);
			let mut fTemp71: F32 = self.fRec35[0] / fTemp69;
			self.fRec32[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec35[0] < (self.fConst5 + fTemp69)) as i32) as i32 != 0) { if (iTemp70 as i32 != 0) { if (((self.fRec35[0] < 0.0) as i32) as i32 != 0) { fTemp67 } else { if (iTemp70 as i32 != 0) { fTemp67 + fTemp68 * if (((self.fRec34[0] > fTemp67) as i32) as i32 != 0) { F32::powf(fTemp71, 0.33333334) } else { fTemp71 } } else { self.fRec34[0] } } } else { self.fRec34[0] } } else { self.fRec34[0] } } else { self.fRec32[1] };
			let mut fTemp72: F32 = self.fRec33[0] - self.fRec32[0];
			let mut fTemp73: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp72) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 4e+01) as i32)) as usize] } * if (((fTemp72 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec32[0])) + 2.0) } else { 0.96 }))));
			self.fRec31[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp73, self.fRec31[1] + 1.0) };
			let mut fTemp74: F32 = self.fRec31[0] / fTemp73;
			let mut fTemp75: F32 = if (((self.fRec31[0] < 0.0) as i32) as i32 != 0) { self.fRec32[0] } else { if (((self.fRec31[0] < fTemp73) as i32) as i32 != 0) { self.fRec32[0] + fTemp72 * if (((self.fRec33[0] > self.fRec32[0]) as i32) as i32 != 0) { F32::powf(fTemp74, 0.33333334) } else { fTemp74 } } else { self.fRec33[0] } };
			let mut iTemp76: i32 = ((fTemp75) as i32);
			let mut fTemp77: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp76) as usize] };
			let mut fRec30: F32 = 0.115 * fTemp66 * (fTemp77 + (fTemp75 - ((iTemp76) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp76, 1)) as usize] } - fTemp77));
			let mut fTemp78: F32 = self.fRec36[1] + fSlow15 * fTemp52;
			self.fRec36[0] = fTemp78 - F32::floor(fTemp78);
			let mut fTemp79: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * (self.fRec36[0] + 17.391304 * (fRec30 + 0.115 * (fTemp66 * (fTemp64 + (fTemp62 - ((iTemp63) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp63, 1)) as usize] } - fTemp64)) + unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec17[0] + 1.024e+04) as i32) % 1024) as usize] } * (fTemp34 + (fTemp32 - ((iTemp33) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp33, 1)) as usize] } - fTemp34)))) + 1e+01)) as i32) % 1024) as usize] } * (fTemp14 + (fTemp12 - ((iTemp13) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp13, 1)) as usize] } - fTemp14));
			self.fVec2[0] = fTemp79;
			self.fRec0[0] = 0.115 * (self.fConst16 * fTemp79 + self.fConst17 * self.fVec2[1]) - self.fConst4 * self.fRec0[1];
			*output0 = fSlow18 * self.fRec0[0];
			*output1 = fSlow19 * self.fRec0[0];
			*output2 = fSlow20 * self.fRec0[0];
			self.fVec0[1] = self.fVec0[0];
			self.fRec5[1] = self.fRec5[0];
			self.fRec4[1] = self.fRec4[0];
			self.fRec6[1] = self.fRec6[0];
			self.fRec8[1] = self.fRec8[0];
			self.fRec9[1] = self.fRec9[0];
			self.fRec3[1] = self.fRec3[0];
			self.fRec2[1] = self.fRec2[0];
			self.fRec13[1] = self.fRec13[0];
			self.fRec14[1] = self.fRec14[0];
			self.fRec15[1] = self.fRec15[0];
			self.fRec16[1] = self.fRec16[0];
			self.fRec12[1] = self.fRec12[0];
			self.fRec11[1] = self.fRec11[0];
			self.iRec21[1] = self.iRec21[0];
			self.iRec22[1] = self.iRec22[0];
			self.fRec23[1] = self.fRec23[0];
			self.fRec20[1] = self.fRec20[0];
			self.fRec19[1] = self.fRec19[0];
			self.fRec17[1] = self.fRec17[0];
			self.fRec26[1] = self.fRec26[0];
			self.fRec27[1] = self.fRec27[0];
			self.fRec28[1] = self.fRec28[0];
			self.fRec25[1] = self.fRec25[0];
			self.fRec24[1] = self.fRec24[0];
			self.fRec29[1] = self.fRec29[0];
			self.fRec33[1] = self.fRec33[0];
			self.fRec34[1] = self.fRec34[0];
			self.fRec35[1] = self.fRec35[0];
			self.fRec32[1] = self.fRec32[0];
			self.fRec31[1] = self.fRec31[0];
			self.fRec36[1] = self.fRec36[0];
			self.fVec2[1] = self.fVec2[0];
			self.fRec0[1] = self.fRec0[0];
		}
	}
}
impl DSP_Cowbell3 {
    /*
       This function was copied from above and
       tweaked to enable auto-vectorization using avx2
    */
    #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
    #[target_feature(enable = "avx2")]
	unsafe fn compute_x86_or_x86_64_using_avx2(&mut self, count: i32, inputs: &[&[<DSP_Cowbell3 as FaustDsp>::T]], outputs: &mut[&mut[<DSP_Cowbell3 as FaustDsp>::T]]) {
		let (outputs0, outputs1, outputs2) = if let [outputs0, outputs1, outputs2, ..] = outputs {
			let outputs0 = outputs0[..count as usize].iter_mut();
			let outputs1 = outputs1[..count as usize].iter_mut();
			let outputs2 = outputs2[..count as usize].iter_mut();
			(outputs0, outputs1, outputs2)
		} else {
			panic!("wrong number of outputs");
		};
		let mut fSlow0: F32 = self.fButton0;
		let mut iSlow1: i32 = ((fSlow0 > 0.0) as i32);
		let mut iSlow2: i32 = ((iSlow1 > 0) as i32);
		let mut fSlow3: F32 = self.fHslider0;
		let mut fSlow4: F32 = self.fEntry0;
		let mut iSlow5: i32 = ((fSlow4 > 0.0) as i32);
		let mut iSlow6: i32 = (((((fSlow0 == 0.0) as i32)) > 0) as i32);
		let mut fSlow7: F32 = ((iSlow1) as F32);
		let mut fSlow8: F32 = F32::powf(2.0, 0.083333336 * (self.fHslider2 + self.fHslider1 + -79.0));
		let mut fSlow9: F32 = 15.996094 * (0.1 * (1.0 - 0.008333334 * (17.31234 * F32::log(fSlow8, std::f32::consts::E) + 48.0)) + 128.0);
		let mut iSlow10: i32 = ((fSlow9) as i32);
		let mut fSlow11: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iSlow10) as usize] };
		let mut fSlow12: F32 = fSlow11 + (fSlow9 - ((iSlow10) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iSlow10, 1)) as usize] } - fSlow11);
		let mut fSlow13: F32 = self.fConst13 * fSlow8;
		let mut fSlow14: F32 = self.fConst14 * fSlow8;
		let mut fSlow15: F32 = self.fConst15 * fSlow8;
		let mut fSlow16: F32 = 0.01 * self.fHslider3;
		let mut fSlow17: F32 = F32::powf(1e+01, 0.05 * F32::max(-1e+02, self.fHslider4 + -2.0));
		let mut fSlow18: F32 = fSlow17 * F32::min(1.0, 1.0 - fSlow16);
		let mut fSlow19: F32 = fSlow17 * F32::min(1.0, fSlow16 + 1.0);
		let mut fSlow20: F32 = 0.01 * self.fHslider5 * fSlow17;
		let zipped_iterators = outputs0.zip(outputs1).zip(outputs2);
		for ((output0, output1), output2) in zipped_iterators {
			self.fVec0[0] = fSlow0;
			let mut iTemp1: i32 = i32::wrapping_sub(1, ((fSlow0 > self.fVec0[1]) as i32));
			self.fRec5[0] = if (iSlow5 as i32 != 0) { fSlow4 } else { self.fRec5[1] };
			let mut fTemp2: F32 = F32::max(0.0, F32::min(127.0, 0.14285715 * (106.0 * (1.0 - DSP_Cowbell3_faustpower2_f(1.0 - F32::max(fSlow3, self.fRec5[0]))) + -99.0) + 85.0));
			let mut fTemp3: F32 = 32.0 * F32::min(1.0, 0.05 * fTemp2) * (fTemp2 + 28.0);
			self.fRec4[0] = if (iTemp1 as i32 != 0) { fTemp3 } else { self.fRec4[1] };
			let mut fTemp4: F32 = F32::max(5076.0, self.fRec4[0]);
			self.fRec6[0] = if (iTemp1 as i32 != 0) { fTemp3 + 4064.0 } else { self.fRec6[1] };
			let mut fTemp5: F32 = self.fRec6[0] - fTemp4;
			self.fRec8[0] = if (iTemp1 as i32 != 0) { 0.0 } else { self.fRec8[1] };
			let mut fTemp6: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp5) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 88.0) as i32)) as usize] } * if (((fTemp5 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp4)) + 2.0) } else { 0.96 }))));
			self.fRec9[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp6, self.fRec9[1] + 1.0) };
			let mut iTemp7: i32 = ((self.fRec9[0] < fTemp6) as i32);
			let mut fTemp8: F32 = self.fRec9[0] / fTemp6;
			self.fRec3[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec9[0] < (self.fConst5 + fTemp6)) as i32) as i32 != 0) { if (iTemp7 as i32 != 0) { if (((self.fRec9[0] < 0.0) as i32) as i32 != 0) { fTemp4 } else { if (iTemp7 as i32 != 0) { fTemp4 + fTemp5 * if (((self.fRec6[0] > fTemp4) as i32) as i32 != 0) { F32::powf(fTemp8, 0.33333334) } else { fTemp8 } } else { self.fRec6[0] } } } else { self.fRec6[0] } } else { self.fRec6[0] } } else { self.fRec3[1] };
			let mut fTemp9: F32 = self.fRec4[0] - self.fRec3[0];
			let mut fTemp10: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp9) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 7e+01) as i32)) as usize] } * if (((fTemp9 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec3[0])) + 2.0) } else { 0.96 }))));
			self.fRec2[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp10, self.fRec2[1] + 1.0) };
			let mut fTemp11: F32 = self.fRec2[0] / fTemp10;
			let mut fTemp12: F32 = if (((self.fRec2[0] < 0.0) as i32) as i32 != 0) { self.fRec3[0] } else { if (((self.fRec2[0] < fTemp10) as i32) as i32 != 0) { self.fRec3[0] + fTemp9 * if (((self.fRec4[0] > self.fRec3[0]) as i32) as i32 != 0) { F32::powf(fTemp11, 0.33333334) } else { fTemp11 } } else { self.fRec4[0] } };
			let mut iTemp13: i32 = ((fTemp12) as i32);
			let mut fTemp14: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp13) as usize] };
			self.fRec13[0] = if (iTemp1 as i32 != 0) { 6944.0 } else { self.fRec13[1] };
			self.fRec14[0] = if (iTemp1 as i32 != 0) { 6.72e+03 } else { self.fRec14[1] };
			let mut fTemp15: F32 = self.fRec14[0] - self.fRec13[0];
			let mut fTemp16: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp15) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 68.0) as i32)) as usize] } * if (((fTemp15 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec13[0])) + 2.0) } else { 0.96 }))));
			self.fRec15[0] = if (iTemp1 as i32 != 0) { 2976.0 } else { self.fRec15[1] };
			let mut fTemp17: F32 = F32::max(5076.0, self.fRec15[0]);
			let mut fTemp18: F32 = self.fRec13[0] - fTemp17;
			let mut fTemp19: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp18) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 94.0) as i32)) as usize] } * if (((fTemp18 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp17)) + 2.0) } else { 0.96 }))));
			let mut fTemp20: F32 = fTemp19 + fTemp16;
			let mut fTemp21: F32 = self.fRec15[0] - self.fRec14[0];
			let mut fTemp22: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp21) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 24.0) as i32)) as usize] } * if (((fTemp21 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec14[0])) + 2.0) } else { 0.96 }))));
			let mut fTemp23: F32 = fTemp20 + fTemp22;
			self.fRec16[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp23, self.fRec16[1] + 1.0) };
			let mut iTemp24: i32 = ((self.fRec16[0] < fTemp20) as i32);
			let mut fTemp25: F32 = (self.fRec16[0] - fTemp20) / fTemp22;
			let mut iTemp26: i32 = ((self.fRec16[0] < fTemp19) as i32);
			let mut fTemp27: F32 = (self.fRec16[0] - fTemp19) / fTemp16;
			let mut fTemp28: F32 = self.fRec16[0] / fTemp19;
			self.fRec12[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp24 as i32 != 0) { if (iTemp26 as i32 != 0) { if (((self.fRec16[0] < 0.0) as i32) as i32 != 0) { fTemp17 } else { if (iTemp26 as i32 != 0) { fTemp17 + fTemp18 * if (((self.fRec13[0] > fTemp17) as i32) as i32 != 0) { F32::powf(fTemp28, 0.33333334) } else { fTemp28 } } else { self.fRec13[0] } } } else { if (iTemp24 as i32 != 0) { self.fRec13[0] + fTemp15 * if (((self.fRec14[0] > self.fRec13[0]) as i32) as i32 != 0) { F32::powf(fTemp27, 0.33333334) } else { fTemp27 } } else { self.fRec14[0] } } } else { if (((self.fRec16[0] < fTemp23) as i32) as i32 != 0) { self.fRec14[0] + fTemp21 * if (((self.fRec15[0] > self.fRec14[0]) as i32) as i32 != 0) { F32::powf(fTemp25, 0.33333334) } else { fTemp25 } } else { self.fRec15[0] } } } else { self.fRec12[1] };
			let mut fTemp29: F32 = self.fRec15[0] - self.fRec12[0];
			let mut fTemp30: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp29) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 55.0) as i32)) as usize] } * if (((fTemp29 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec12[0])) + 2.0) } else { 0.96 }))));
			self.fRec11[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp30, self.fRec11[1] + 1.0) };
			let mut fTemp31: F32 = self.fRec11[0] / fTemp30;
			let mut fTemp32: F32 = if (((self.fRec11[0] < 0.0) as i32) as i32 != 0) { self.fRec12[0] } else { if (((self.fRec11[0] < fTemp30) as i32) as i32 != 0) { self.fRec12[0] + fTemp29 * if (((self.fRec15[0] > self.fRec12[0]) as i32) as i32 != 0) { F32::powf(fTemp31, 0.33333334) } else { fTemp31 } } else { self.fRec15[0] } };
			let mut iTemp33: i32 = ((fTemp32) as i32);
			let mut fTemp34: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp33) as usize] };
			self.iRec21[0] = if (iTemp1 as i32 != 0) { self.iConst9 } else { self.iRec21[1] };
			self.iRec22[0] = if (iTemp1 as i32 != 0) { self.iConst10 } else { self.iRec22[1] };
			let mut iTemp35: i32 = i32::wrapping_sub(self.iRec22[0], self.iRec21[0]);
			let mut fTemp36: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp35)) as F32) / self.fConst8));
			let mut iTemp37: i32 = i32::wrapping_sub(self.iRec21[0], self.iRec22[0]);
			let mut fTemp38: F32 = F32::max(1.0, self.fConst11 * (((i32::abs(iTemp37)) as F32) / self.fConst12));
			let mut fTemp39: F32 = fTemp38 + fTemp36;
			self.fRec23[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(fTemp39 + 1.0, self.fRec23[1] + 1.0) };
			let mut iTemp40: i32 = ((self.fRec23[0] < fTemp39) as i32);
			let mut fTemp41: F32 = ((self.iRec22[0]) as F32);
			let mut iTemp42: i32 = ((self.fRec23[0] < fTemp38) as i32);
			let mut fTemp43: F32 = (self.fRec23[0] - fTemp38) / fTemp36;
			let mut fTemp44: F32 = ((self.iRec21[0]) as F32);
			let mut fTemp45: F32 = self.fRec23[0] / fTemp38;
			self.fRec20[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (iTemp40 as i32 != 0) { if (iTemp42 as i32 != 0) { if (((self.fRec23[0] < 0.0) as i32) as i32 != 0) { fTemp41 } else { if (iTemp42 as i32 != 0) { fTemp41 + ((iTemp37) as F32) * if (((self.iRec21[0] > self.iRec22[0]) as i32) as i32 != 0) { F32::powf(fTemp45, 0.33333334) } else { fTemp45 } } else { fTemp44 } } } else { if (iTemp40 as i32 != 0) { fTemp44 + ((iTemp35) as F32) * if (((self.iRec22[0] > self.iRec21[0]) as i32) as i32 != 0) { F32::powf(fTemp43, 0.33333334) } else { fTemp43 } } else { fTemp41 } } } else { fTemp41 } } else { self.fRec20[1] };
			let mut fTemp46: F32 = fTemp41 - self.fRec20[0];
			let mut fTemp47: F32 = F32::max(1.0, self.fConst11 * (F32::abs(fTemp46) / self.fConst7));
			self.fRec19[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp47, self.fRec19[1] + 1.0) };
			let mut fTemp48: F32 = self.fRec19[0] / fTemp47;
			let mut fTemp49: F32 = 15.996094 * (0.4 * if (((self.fRec19[0] < 0.0) as i32) as i32 != 0) { self.fRec20[0] } else { if (((self.fRec19[0] < fTemp47) as i32) as i32 != 0) { self.fRec20[0] + fTemp46 * if (((fTemp41 > self.fRec20[0]) as i32) as i32 != 0) { F32::powf(fTemp48, 0.33333334) } else { fTemp48 } } else { fTemp41 } } + 128.0);
			let mut iTemp50: i32 = ((fTemp49) as i32);
			let mut fTemp51: F32 = unsafe { ftbl3DSP_Cowbell3SIG3[(iTemp50) as usize] };
			let mut fTemp52: F32 = fSlow12 * (fTemp51 + (fTemp49 - ((iTemp50) as F32)) * (unsafe { ftbl3DSP_Cowbell3SIG3[(i32::wrapping_add(iTemp50, 1)) as usize] } - fTemp51));
			let mut fTemp53: F32 = self.fRec17[1] + fSlow13 * fTemp52;
			self.fRec17[0] = fTemp53 - F32::floor(fTemp53);
			self.fRec26[0] = if (iTemp1 as i32 != 0) { 3872.0 } else { self.fRec26[1] };
			let mut fTemp54: F32 = F32::max(5076.0, self.fRec26[0]);
			self.fRec27[0] = if (iTemp1 as i32 != 0) { 7936.0 } else { self.fRec27[1] };
			let mut fTemp55: F32 = self.fRec27[0] - fTemp54;
			let mut fTemp56: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp55) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 71.0) as i32)) as usize] } * if (((fTemp55 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp54)) + 2.0) } else { 0.96 }))));
			self.fRec28[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp56, self.fRec28[1] + 1.0) };
			let mut iTemp57: i32 = ((self.fRec28[0] < fTemp56) as i32);
			let mut fTemp58: F32 = self.fRec28[0] / fTemp56;
			self.fRec25[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec28[0] < (self.fConst5 + fTemp56)) as i32) as i32 != 0) { if (iTemp57 as i32 != 0) { if (((self.fRec28[0] < 0.0) as i32) as i32 != 0) { fTemp54 } else { if (iTemp57 as i32 != 0) { fTemp54 + fTemp55 * if (((self.fRec27[0] > fTemp54) as i32) as i32 != 0) { F32::powf(fTemp58, 0.33333334) } else { fTemp58 } } else { self.fRec27[0] } } } else { self.fRec27[0] } } else { self.fRec27[0] } } else { self.fRec25[1] };
			let mut fTemp59: F32 = self.fRec26[0] - self.fRec25[0];
			let mut fTemp60: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp59) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 51.0) as i32)) as usize] } * if (((fTemp59 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec25[0])) + 2.0) } else { 0.96 }))));
			self.fRec24[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp60, self.fRec24[1] + 1.0) };
			let mut fTemp61: F32 = self.fRec24[0] / fTemp60;
			let mut fTemp62: F32 = if (((self.fRec24[0] < 0.0) as i32) as i32 != 0) { self.fRec25[0] } else { if (((self.fRec24[0] < fTemp60) as i32) as i32 != 0) { self.fRec25[0] + fTemp59 * if (((self.fRec26[0] > self.fRec25[0]) as i32) as i32 != 0) { F32::powf(fTemp61, 0.33333334) } else { fTemp61 } } else { self.fRec26[0] } };
			let mut iTemp63: i32 = ((fTemp62) as i32);
			let mut fTemp64: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp63) as usize] };
			let mut fTemp65: F32 = self.fRec29[1] + fSlow14 * fTemp52;
			self.fRec29[0] = fTemp65 - F32::floor(fTemp65);
			let mut fTemp66: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec29[0] + 1.024e+04) as i32) % 1024) as usize] };
			self.fRec33[0] = if (iTemp1 as i32 != 0) { 3.04e+03 } else { self.fRec33[1] };
			let mut fTemp67: F32 = F32::max(5076.0, self.fRec33[0]);
			self.fRec34[0] = if (iTemp1 as i32 != 0) { 7104.0 } else { self.fRec34[1] };
			let mut fTemp68: F32 = self.fRec34[0] - fTemp67;
			let mut fTemp69: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp68) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 67.0) as i32)) as usize] } * if (((fTemp68 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - fTemp67)) + 2.0) } else { 0.96 }))));
			self.fRec35[0] = if (iSlow6 as i32 != 0) { 0.0 } else { F32::min(self.fConst6 + fTemp69, self.fRec35[1] + 1.0) };
			let mut iTemp70: i32 = ((self.fRec35[0] < fTemp69) as i32);
			let mut fTemp71: F32 = self.fRec35[0] / fTemp69;
			self.fRec32[0] = if (iSlow1 as i32 != 0) { fSlow7 * if (((self.fRec35[0] < (self.fConst5 + fTemp69)) as i32) as i32 != 0) { if (iTemp70 as i32 != 0) { if (((self.fRec35[0] < 0.0) as i32) as i32 != 0) { fTemp67 } else { if (iTemp70 as i32 != 0) { fTemp67 + fTemp68 * if (((self.fRec34[0] > fTemp67) as i32) as i32 != 0) { F32::powf(fTemp71, 0.33333334) } else { fTemp71 } } else { self.fRec34[0] } } } else { self.fRec34[0] } } else { self.fRec34[0] } } else { self.fRec32[1] };
			let mut fTemp72: F32 = self.fRec33[0] - self.fRec32[0];
			let mut fTemp73: F32 = F32::max(1.0, self.fConst0 * F32::max(0.001, 0.0235 * (F32::abs(fTemp72) / (unsafe { ftbl1DSP_Cowbell3SIG1[(((self.fRec8[0] + 4e+01) as i32)) as usize] } * if (((fTemp72 > 0.0) as i32) as i32 != 0) { 0.538 * (F32::max(0.0, 0.00390625 * (7.2e+03 - self.fRec32[0])) + 2.0) } else { 0.96 }))));
			self.fRec31[0] = if (iSlow2 as i32 != 0) { 0.0 } else { F32::min(fTemp73, self.fRec31[1] + 1.0) };
			let mut fTemp74: F32 = self.fRec31[0] / fTemp73;
			let mut fTemp75: F32 = if (((self.fRec31[0] < 0.0) as i32) as i32 != 0) { self.fRec32[0] } else { if (((self.fRec31[0] < fTemp73) as i32) as i32 != 0) { self.fRec32[0] + fTemp72 * if (((self.fRec33[0] > self.fRec32[0]) as i32) as i32 != 0) { F32::powf(fTemp74, 0.33333334) } else { fTemp74 } } else { self.fRec33[0] } };
			let mut iTemp76: i32 = ((fTemp75) as i32);
			let mut fTemp77: F32 = unsafe { ftbl0DSP_Cowbell3SIG0[(iTemp76) as usize] };
			let mut fRec30: F32 = 0.115 * fTemp66 * (fTemp77 + (fTemp75 - ((iTemp76) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp76, 1)) as usize] } - fTemp77));
			let mut fTemp78: F32 = self.fRec36[1] + fSlow15 * fTemp52;
			self.fRec36[0] = fTemp78 - F32::floor(fTemp78);
			let mut fTemp79: F32 = unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * (self.fRec36[0] + 17.391304 * (fRec30 + 0.115 * (fTemp66 * (fTemp64 + (fTemp62 - ((iTemp63) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp63, 1)) as usize] } - fTemp64)) + unsafe { ftbl2DSP_Cowbell3SIG2[(((1024.0 * self.fRec17[0] + 1.024e+04) as i32) % 1024) as usize] } * (fTemp34 + (fTemp32 - ((iTemp33) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp33, 1)) as usize] } - fTemp34)))) + 1e+01)) as i32) % 1024) as usize] } * (fTemp14 + (fTemp12 - ((iTemp13) as F32)) * (unsafe { ftbl0DSP_Cowbell3SIG0[(i32::wrapping_add(iTemp13, 1)) as usize] } - fTemp14));
			self.fVec2[0] = fTemp79;
			self.fRec0[0] = 0.115 * (self.fConst16 * fTemp79 + self.fConst17 * self.fVec2[1]) - self.fConst4 * self.fRec0[1];
			*output0 = fSlow18 * self.fRec0[0];
			*output1 = fSlow19 * self.fRec0[0];
			*output2 = fSlow20 * self.fRec0[0];
			self.fVec0[1] = self.fVec0[0];
			self.fRec5[1] = self.fRec5[0];
			self.fRec4[1] = self.fRec4[0];
			self.fRec6[1] = self.fRec6[0];
			self.fRec8[1] = self.fRec8[0];
			self.fRec9[1] = self.fRec9[0];
			self.fRec3[1] = self.fRec3[0];
			self.fRec2[1] = self.fRec2[0];
			self.fRec13[1] = self.fRec13[0];
			self.fRec14[1] = self.fRec14[0];
			self.fRec15[1] = self.fRec15[0];
			self.fRec16[1] = self.fRec16[0];
			self.fRec12[1] = self.fRec12[0];
			self.fRec11[1] = self.fRec11[0];
			self.iRec21[1] = self.iRec21[0];
			self.iRec22[1] = self.iRec22[0];
			self.fRec23[1] = self.fRec23[0];
			self.fRec20[1] = self.fRec20[0];
			self.fRec19[1] = self.fRec19[0];
			self.fRec17[1] = self.fRec17[0];
			self.fRec26[1] = self.fRec26[0];
			self.fRec27[1] = self.fRec27[0];
			self.fRec28[1] = self.fRec28[0];
			self.fRec25[1] = self.fRec25[0];
			self.fRec24[1] = self.fRec24[0];
			self.fRec29[1] = self.fRec29[0];
			self.fRec33[1] = self.fRec33[0];
			self.fRec34[1] = self.fRec34[0];
			self.fRec35[1] = self.fRec35[0];
			self.fRec32[1] = self.fRec32[0];
			self.fRec31[1] = self.fRec31[0];
			self.fRec36[1] = self.fRec36[0];
			self.fVec2[1] = self.fVec2[0];
			self.fRec0[1] = self.fRec0[0];
		}
	}
}
